@@ -13,8 +13,8 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with with program; see the file COPYING. If not, write to the
- *  Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
- *  MA  02111-1307  USA
+ *  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ *  MA  02110-1301  USA
  */
 
 #include <lal/LALHough.h>
@@ -48,7 +48,7 @@ static void LALComputeAM (LALStatus *, AMCoeffs *coe, LIGOTimeGPS *ts, AMCoeffsP
  * <tt>phmdVS->nfSize</tt>. At this moment the \c fBinMin line corresponds to the
  * first row of the cylinder and <tt>phmdVS->breakLine</tt> is set to zero.
  * <tt>phmdVS->breakLine</tt>
- * \f$\in\, [0,\f$\c nfSize) is <em>the pointer</em> which
+ * \f$ \in\, [0, \f$ \c nfSize) is <em>the pointer</em> which
  * identifies the position of the  \c fBinMin row in the circular-cylinder buffer.
  */
 void LALHOUGHConstructSpacePHMD  (LALStatus            *status,	/**< pointer to LALStatus structure */
@@ -98,14 +98,12 @@ void LALHOUGHConstructSpacePHMD  (LALStatus            *status,	/**< pointer to
   length = phmdVS->length;
   nfSize = phmdVS->nfSize;
   fBinMin = phmdVS->fBinMin;
-#ifndef LAL_NDEBUG
-  REAL8 deltaF =  phmdVS->deltaF = lutV->lut[0].deltaF;   /* frequency resolution */
-#endif
+  phmdVS->deltaF = lutV->lut[0].deltaF;   /* frequency resolution */
 
   for ( k=0; k<length; ++k ){
 
     /* make sure all deltaF are consistent */
-    ASSERT (deltaF == lutV->lut[k].deltaF,
+    ASSERT (phmdVS->deltaF == lutV->lut[k].deltaF,
 	    status, LALHOUGHH_EVAL, LALHOUGHH_MSGEVAL);
 
     fBin = fBinMin;
@@ -172,9 +170,6 @@ void LALHOUGHupdateSpacePHMDup  (LALStatus            *status,
 
   length = phmdVS->length;
   nfSize = phmdVS->nfSize;
-#ifndef LAL_NDEBUG
-  REAL8 deltaF =  phmdVS->deltaF;
-#endif
 
   breakLine = phmdVS->breakLine; /* old Break Line */
   fBinMin = phmdVS->fBinMin; /* initial frequency value  */
@@ -190,7 +185,7 @@ void LALHOUGHupdateSpacePHMDup  (LALStatus            *status,
 
   for ( k=0; k<length; ++k ){
     /* make sure all deltaF are consistent */
-    ASSERT (deltaF == lutV->lut[k].deltaF,
+    ASSERT (phmdVS->deltaF == lutV->lut[k].deltaF,
 	    status, LALHOUGHH_EVAL, LALHOUGHH_MSGEVAL);
 
     phmdVS->phmd[ breakLine*length+k ].fBin = fBin;
@@ -258,9 +253,6 @@ void LALHOUGHupdateSpacePHMDdn  (LALStatus            *status,
 
   length = phmdVS->length;
   nfSize = phmdVS->nfSize;
-#ifndef LAL_NDEBUG
-  REAL8 deltaF =  phmdVS->deltaF;
-#endif
 
   breakLine = phmdVS->breakLine; /* old Break Line */
 
@@ -282,7 +274,7 @@ void LALHOUGHupdateSpacePHMDdn  (LALStatus            *status,
 
   for ( k=0; k<length; ++k ){
     /* make sure all deltaF are consistent */
-    ASSERT (deltaF == lutV->lut[k].deltaF,
+    ASSERT (phmdVS->deltaF == lutV->lut[k].deltaF,
 	    status, LALHOUGHH_EVAL, LALHOUGHH_MSGEVAL);
 
     phmdVS->phmd[ breakLine*length+k ].fBin = fBin;
