@@ -25,8 +25,6 @@ from __future__ import division, absolute_import, print_function
 import os
 import re
 
-from six import string_types
-
 import numpy as np
 
 from astropy import units as u
@@ -35,161 +33,180 @@ import lal
 import lalpulsar
 
 # set units of parameters in the PulsarParameters structure
-PPUNITS = {'F':            u.Hz,                     # Hz
-           'P':            u.s,                      # seconds
-           'DIST':         u.m,                      # metres
-           'PX':           u.rad,                    # radians
-           'DM':           u.pc/(u.cm)**3,           # cm^-3 pc
-           'DM1':          u.pc/(u.cm**3*u.yr),      # pc cm^-3 yr^-1
-           'RA':           u.rad,                    # radians
-           'RAJ':          u.rad,                    # radians
-           'DEC':          u.rad,                    # radians
-           'DECJ':         u.rad,                    # radians
-           'PMRA':         u.rad/u.s,                # rad/s
-           'PMDEC':        u.rad/u.s,                # rad/s
-           'ELONG':        u.rad,                    # rad
-           'ELAT':         u.rad,                    # rad
-           'PEPOCH':       u.s,                      # GPS seconds
-           'POSEPOCH':     u.s,                      # GPS seconds
-           'DMEPOCH':      u.s,                      # GPS seconds
-           'GLEP':         u.s,                      # GPS seconds
-           'GLPH':         u.rad,                    # rad
-           'GLF0':         u.Hz,                     # Hz
-           'GLF1':         u.Hz/u.s,                 # Hz/s
-           'GLF2':         u.Hz/u.s**2,              # Hz s^-2
-           'GLF0D':        u.Hz,                     # Hz
-           'GLTD':         u.s,                      # sec
-           'A1':           u.s,                      # light seconds
-           'OM':           u.rad,                    # rad
-           'PB':           u.s,                      # seconds
-           'T0':           u.s,                      # GPS seconds
-           'TASC':         u.s,                      # GPS seconds
-           'EPS1':         u.dimensionless_unscaled,
-           'EPS2':         u.dimensionless_unscaled,
-           'GAMMA':        u.s,                      # seconds
-           'OMDOT':        u.rad/u.s,                # rad/s
-           'XDOT':         u.s/u.s,                  # light seconds/sec
-           'PBDOT':        u.s/u.s,                  # s/s
-           'EDOT':         1./u.s,                   # 1/sec
-           'EPSDOT1':      1./u.s,                   # 1/sec
-           'EPSDOT2':      1./u.s,                   # 1/sec
-           'XPBDOT':       u.s/u.s,                  # s/s
-           'SINI':         u.dimensionless_unscaled,
-           'MTOT':         u.kg,                     # kg
-           'M2':           u.kg,                     # kg
-           'DR':           u.dimensionless_unscaled,
-           'DTHETA':       u.dimensionless_unscaled,
-           'SHAPMAX':      u.dimensionless_unscaled,
-           'A1_2':         u.s,                      # light seconds
-           'A1_3':         u.s,                      # light seconds
-           'OM_2':         u.rad,                    # radians
-           'OM_3':         u.rad,                    # radians
-           'PB_2':         u.s,                      # seconds
-           'PB_3':         u.s,                      # seconds
-           'T0_2':         u.s,                      # GPS seconds
-           'T0_3':         u.s,                      # GPS seconds
-           'FB':           u.Hz,                     # Hz
-           'A0':           u.s,                      # seconds
-           'B0':           u.s,                      # seconds
-           'D_AOP':        1./u.rad,                 # 1/rad
-           'KIN':          u.rad,                    # radians
-           'KOM':          u.rad,                    # radians
-           'WAVE_OM':      u.Hz,                     # Hz
-           'WAVEEPOCH':    u.s,                      # GPS seconds
-           'WAVESIN':      u.s,                      # seconds
-           'WAVECOS':      u.s,                      # seconds
-           'START':        u.s,                      # GPS seconds
-           'FINISH':       u.s,                      # GPS seconds
-           'TRES':         u.s,                      # seconds
-           'H0':           u.dimensionless_unscaled,
-           'APLUS':        u.dimensionless_unscaled,
-           'ACROSS':       u.dimensionless_unscaled,
-           'PHI0':         u.rad,                    # radians
-           'PSI':          u.rad,                    # radians
-           'COSIOTA':      u.dimensionless_unscaled,
-           'IOTA':         u.rad,                    # radians
-           'C22':          u.dimensionless_unscaled,
-           'C21':          u.dimensionless_unscaled,
-           'PHI22':        u.rad,                    # radians
-           'PHI21':        u.rad,                    # radians
-           'CGW':          u.dimensionless_unscaled,
-           'LAMBDA':       u.rad,                    # radians
-           'COSTHETA':     u.dimensionless_unscaled,
-           'THETA':        u.rad,
-           'I21':          u.dimensionless_unscaled,
-           'I31':          u.dimensionless_unscaled,
-           'Q22':          u.kg*u.m**2,              # kg m^2
-           'H0_F':         u.dimensionless_unscaled,
-           'HPLUS':        u.dimensionless_unscaled,
-           'HCROSS':       u.dimensionless_unscaled,
-           'PSITENSOR':    u.rad,                    # radians
-           'PHI0TENSOR':   u.rad,                    # radians
-           'HSCALARB':     u.dimensionless_unscaled,
-           'HSCALARL':     u.dimensionless_unscaled,
-           'PSISCALAR':    u.rad,                    # radians
-           'PHI0SCALAR':   u.rad,                    # radians
-           'HVECTORX':     u.dimensionless_unscaled,
-           'HVECTORY':     u.dimensionless_unscaled,
-           'PSIVECTOR':    u.rad,                    # radians
-           'PHI0VECTOR':   u.rad,                    # radians
-           'HPLUS_F':      u.dimensionless_unscaled,
-           'HCROSS_F':     u.dimensionless_unscaled,
-           'PSITENSOR_F':  u.rad,                    # radians
-           'PHI0TENSOR_F': u.rad,                    # radians
-           'HSCALARB_F':   u.dimensionless_unscaled,
-           'HSCALARL_F':   u.dimensionless_unscaled,
-           'PSISCALAR_F':  u.rad,                    # radians
-           'PHI0SCALAR_F': u.rad,                    # radians
-           'HVECTORX_F':   u.dimensionless_unscaled,
-           'HVECTORY_F':   u.dimensionless_unscaled,
-           'PSIVECTOR_F':  u.rad,                    # radians
-           'PHI0VECTOR_F': u.rad                     # radians
-          }
+PPUNITS = {
+    "F": u.Hz,  # Hz
+    "P": u.s,  # seconds
+    "DIST": u.m,  # metres
+    "PX": u.rad,  # radians
+    "DM": u.pc / (u.cm) ** 3,  # cm^-3 pc
+    "DM1": u.pc / (u.cm**3 * u.yr),  # pc cm^-3 yr^-1
+    "RA": u.rad,  # radians
+    "RAJ": u.rad,  # radians
+    "DEC": u.rad,  # radians
+    "DECJ": u.rad,  # radians
+    "PMRA": u.rad / u.s,  # rad/s
+    "PMDEC": u.rad / u.s,  # rad/s
+    "ELONG": u.rad,  # rad
+    "ELAT": u.rad,  # rad
+    "PMELONG": u.rad,  # rad/s
+    "PMELAT": u.rad,  # rad/s
+    "BETA": u.rad,  # rad
+    "LAMBDA": u.rad,  # rad
+    "PMBETA": u.rad,  # rad/s
+    "PMLAMBDA": u.rad,  # rad/s
+    "PEPOCH": u.s,  # GPS seconds
+    "POSEPOCH": u.s,  # GPS seconds
+    "DMEPOCH": u.s,  # GPS seconds
+    "GLEP": u.s,  # GPS seconds
+    "GLPH": u.rad,  # rad
+    "GLF0": u.Hz,  # Hz
+    "GLF1": u.Hz / u.s,  # Hz/s
+    "GLF2": u.Hz / u.s**2,  # Hz s^-2
+    "GLF0D": u.Hz,  # Hz
+    "GLTD": u.s,  # sec
+    "A1": u.s,  # light seconds
+    "OM": u.rad,  # rad
+    "PB": u.s,  # seconds
+    "T0": u.s,  # GPS seconds
+    "TASC": u.s,  # GPS seconds
+    "EPS1": u.dimensionless_unscaled,
+    "EPS2": u.dimensionless_unscaled,
+    "GAMMA": u.s,  # seconds
+    "OMDOT": u.rad / u.s,  # rad/s
+    "XDOT": u.s / u.s,  # light seconds/sec
+    "PBDOT": u.s / u.s,  # s/s
+    "EDOT": 1.0 / u.s,  # 1/sec
+    "EPSDOT1": 1.0 / u.s,  # 1/sec
+    "EPSDOT2": 1.0 / u.s,  # 1/sec
+    "XPBDOT": u.s / u.s,  # s/s
+    "SINI": u.dimensionless_unscaled,
+    "MTOT": u.kg,  # kg
+    "M2": u.kg,  # kg
+    "DR": u.dimensionless_unscaled,
+    "DTHETA": u.dimensionless_unscaled,
+    "SHAPMAX": u.dimensionless_unscaled,
+    "A1_2": u.s,  # light seconds
+    "A1_3": u.s,  # light seconds
+    "OM_2": u.rad,  # radians
+    "OM_3": u.rad,  # radians
+    "PB_2": u.s,  # seconds
+    "PB_3": u.s,  # seconds
+    "T0_2": u.s,  # GPS seconds
+    "T0_3": u.s,  # GPS seconds
+    "FB": u.Hz,  # Hz
+    "A0": u.s,  # seconds
+    "B0": u.s,  # seconds
+    "D_AOP": 1.0 / u.rad,  # 1/rad
+    "KIN": u.rad,  # radians
+    "KOM": u.rad,  # radians
+    "WAVE_OM": u.Hz,  # Hz
+    "WAVEEPOCH": u.s,  # GPS seconds
+    "WAVESIN": u.s,  # seconds
+    "WAVECOS": u.s,  # seconds
+    "START": u.s,  # GPS seconds
+    "FINISH": u.s,  # GPS seconds
+    "TRES": u.s,  # seconds
+    "H0": u.dimensionless_unscaled,
+    "APLUS": u.dimensionless_unscaled,
+    "ACROSS": u.dimensionless_unscaled,
+    "PHI0": u.rad,  # radians
+    "PSI": u.rad,  # radians
+    "COSIOTA": u.dimensionless_unscaled,
+    "IOTA": u.rad,  # radians
+    "C22": u.dimensionless_unscaled,
+    "C21": u.dimensionless_unscaled,
+    "PHI22": u.rad,  # radians
+    "PHI21": u.rad,  # radians
+    "CGW": u.dimensionless_unscaled,
+    "LAMBDAPIN": u.rad,  # radians
+    "COSTHETA": u.dimensionless_unscaled,
+    "THETA": u.rad,
+    "I21": u.dimensionless_unscaled,
+    "I31": u.dimensionless_unscaled,
+    "Q22": u.kg * u.m**2,  # kg m^2
+    "H0_F": u.dimensionless_unscaled,
+    "HPLUS": u.dimensionless_unscaled,
+    "HCROSS": u.dimensionless_unscaled,
+    "PSITENSOR": u.rad,  # radians
+    "PHI0TENSOR": u.rad,  # radians
+    "HSCALARB": u.dimensionless_unscaled,
+    "HSCALARL": u.dimensionless_unscaled,
+    "PSISCALAR": u.rad,  # radians
+    "PHI0SCALAR": u.rad,  # radians
+    "HVECTORX": u.dimensionless_unscaled,
+    "HVECTORY": u.dimensionless_unscaled,
+    "PSIVECTOR": u.rad,  # radians
+    "PHI0VECTOR": u.rad,  # radians
+    "HPLUS_F": u.dimensionless_unscaled,
+    "HCROSS_F": u.dimensionless_unscaled,
+    "PSITENSOR_F": u.rad,  # radians
+    "PHI0TENSOR_F": u.rad,  # radians
+    "HSCALARB_F": u.dimensionless_unscaled,
+    "HSCALARL_F": u.dimensionless_unscaled,
+    "PSISCALAR_F": u.rad,  # radians
+    "PHI0SCALAR_F": u.rad,  # radians
+    "HVECTORX_F": u.dimensionless_unscaled,
+    "HVECTORY_F": u.dimensionless_unscaled,
+    "PSIVECTOR_F": u.rad,  # radians
+    "PHI0VECTOR_F": u.rad,  # radians
+    "TRANSIENTSTARTTIME": u.s,  # GPS seconds
+    "TRANSIENTTAU": u.s,  # seconds
+}
 
 # set units of parameters in a TEMPO-style parameter file if different from above
-TEMPOUNITS = {'DIST':      u.kpc,                  # kpc
-              'PX':        u.mas,                  # milliarcsecs
-              'RA':        u.hourangle,            # hh:mm:ss.s
-              'RAJ':       u.hourangle,            # hh:mm:ss.s
-              'DEC':       u.deg,                  # hh:mm:ss.s
-              'DECJ':      u.deg,                  # hh:mm:ss.s
-              'PMRA':      u.mas/u.yr,             # milliarcsecs/year
-              'PMDEC':     u.mas/u.yr,             # milliarcsecs/year
-              'ELONG':     u.deg,                  # degrees
-              'ELAT':      u.deg,                  # degrees
-              'PEPOCH':    u.d,                    # MJD(TT) (day)
-              'POSEPOCH':  u.d,                    # MJD(TT) (day)
-              'DMEPOCH':   u.d,                    # MJD(TT) (day)
-              'GLEP':      u.d,                    # MJD(TT) (day)
-              'GLTD':      u.d,                    # days
-              'OM':        u.deg,                  # degs
-              'PB':        u.d,                    # day
-              'T0':        u.d,                    # MJD(TT) (day)
-              'TASC':      u.d,                    # MJD(TT) (day)
-              'OMDOT':     u.deg/u.yr,             # deg/yr
-              'MTOT':      u.solMass,              # M_sun
-              'M2':        u.solMass,              # M_sun
-              'OM_2':      u.deg,                  # degrees
-              'OM_3':      u.deg,                  # degrees
-              'PB_2':      u.d,                    # days
-              'PB_3':      u.d,                    # days
-              'T0_2':      u.d,                    # MJD(TT) (days)
-              'T0_3':      u.d,                    # MJD(TT) (days)
-              'D_AOP':     1./u.arcsec,            # 1/arcsec
-              'KIN':       u.deg,                  # degrees
-              'KOM':       u.deg,                  # degrees
-              'WAVEEPOCH': u.d,                    # MJD(TT) (days)
-              'START':     u.d,                    # MJD(TT) (days)
-              'FINISH':    u.d,                    # MJD(TT) (days)
-              'TRES':      u.us                    # microsecs
-             }
+TEMPOUNITS = {
+    "DIST": u.kpc,  # kpc
+    "PX": u.mas,  # milliarcsecs
+    "RA": u.hourangle,  # hh:mm:ss.s
+    "RAJ": u.hourangle,  # hh:mm:ss.s
+    "DEC": u.deg,  # hh:mm:ss.s
+    "DECJ": u.deg,  # hh:mm:ss.s
+    "PMRA": u.mas / u.yr,  # milliarcsecs/year
+    "PMDEC": u.mas / u.yr,  # milliarcsecs/year
+    "ELONG": u.deg,  # degrees
+    "ELAT": u.deg,  # degrees
+    "PMELONG": u.mas / u.yr,  # milliarcsecs/year
+    "PMELAT": u.mas / u.yr,  # milliarcsecs/year
+    "BETA": u.deg,
+    "LAMBDA": u.deg,
+    "PMBETA": u.mas / u.yr,
+    "PMLAMBDA": u.mas / u.yr,
+    "PEPOCH": u.d,  # MJD(TT) (day)
+    "POSEPOCH": u.d,  # MJD(TT) (day)
+    "DMEPOCH": u.d,  # MJD(TT) (day)
+    "GLEP": u.d,  # MJD(TT) (day)
+    "GLTD": u.d,  # days
+    "OM": u.deg,  # degs
+    "PB": u.d,  # day
+    "T0": u.d,  # MJD(TT) (day)
+    "TASC": u.d,  # MJD(TT) (day)
+    "OMDOT": u.deg / u.yr,  # deg/yr
+    "MTOT": u.solMass,  # M_sun
+    "M2": u.solMass,  # M_sun
+    "OM_2": u.deg,  # degrees
+    "OM_3": u.deg,  # degrees
+    "PB_2": u.d,  # days
+    "PB_3": u.d,  # days
+    "T0_2": u.d,  # MJD(TT) (days)
+    "T0_3": u.d,  # MJD(TT) (days)
+    "D_AOP": 1.0 / u.arcsec,  # 1/arcsec
+    "KIN": u.deg,  # degrees
+    "KOM": u.deg,  # degrees
+    "WAVEEPOCH": u.d,  # MJD(TT) (days)
+    "START": u.d,  # MJD(TT) (days)
+    "FINISH": u.d,  # MJD(TT) (days)
+    "TRES": u.us,  # microsecs
+    "TRANSIENTSTARTTIME": u.d,  # MJD(TT) (day)
+    "TRANSIENTTAU": u.d,  # days
+}
 
 # set units of error values in tempo if different from above
-TEMPOERRUNITS = {'RA':   u.s,                      # second
-                 'RAJ':  u.s,                      # second
-                 'DEC':  u.arcsec,                 # arcsecond
-                 'DECJ': u.arcsec                  # arcsecond
-                }
+TEMPOERRUNITS = {
+    "RA": u.s,  # second
+    "RAJ": u.s,  # second
+    "DEC": u.arcsec,  # arcsecond
+    "DECJ": u.arcsec,  # arcsecond
+}
 
 
 class PulsarParametersPy(object):
@@ -234,11 +251,10 @@ class PulsarParametersPy(object):
             >>> pppy = PulsarParametersPy()
             >>> pppy.read('apulsar.par')
 
-         parameter can be set in the class using, e.g.
     """
 
-    keynames = []   # parameter names in PulsarParameters structure
-    length = 0      # number of parameters
+    keynames = []  # parameter names in PulsarParameters structure
+    length = 0  # number of parameters
     _pulsarparameters = None
 
     def __init__(self, pp=None):
@@ -247,7 +263,7 @@ class PulsarParametersPy(object):
             self._pulsarparameters = lalpulsar.PulsarParameters()
         else:
             # check if pp is a pulsar parameters type or a (par file)
-            if not isinstance(pp, lalpulsar.PulsarParameters) and isinstance(pp, string_types):
+            if not isinstance(pp, lalpulsar.PulsarParameters) and isinstance(pp, str):
                 if os.path.isfile(pp):
                     # try reading in file
                     self.read(pp)
@@ -256,7 +272,9 @@ class PulsarParametersPy(object):
             elif isinstance(pp, lalpulsar.PulsarParameters):
                 self._pulsarparameters = pp
             else:
-                raise ValueError("Expected 'lalpulsar.PulsarParameters' type, string, or None")
+                raise ValueError(
+                    "Expected 'lalpulsar.PulsarParameters' type, string, or None"
+                )
 
     def __len__(self):
         _ = self.keys()  # length is counted in the keys() method
@@ -279,26 +297,28 @@ class PulsarParametersPy(object):
         tkey = key
         if key[-4:].upper() == "_ERR":
             geterr = True
-            tkey = key[:-4] # get the actual parameter key name
+            tkey = key[:-4]  # get the actual parameter key name
 
         # check if the key is asking for an individual parameter from a vector parameter
         # (e.g. 'F0' gets the first value from the 'F' vector.
         # NOTE: this is problematic for glitch parameters, e.g., GLF0, which could provide
         # values to multiple glitches, so this cannot be used to get individual glitch
         # parameters).
-        sname = re.sub(r'_\d', '', tkey) if '_' in tkey else re.sub(r'\d', '', tkey)
+        sname = re.sub(r"_\d", "", tkey) if "_" in tkey else re.sub(r"\d", "", tkey)
         sidx = None
         indkey = None
         if sname != tkey and tkey[0:2] != "GL":
             # check additional index is an integer
             try:
-                sidx = int(tkey.split('_')[-1]) if '_' in tkey else int(tkey[len(sname):])
+                sidx = (
+                    int(tkey.split("_")[-1]) if "_" in tkey else int(tkey[len(sname) :])
+                )
             except ValueError:
                 pass
 
             # change tkey for checking parameter exists
             if sidx is not None:
-                indkey = tkey # key with index
+                indkey = tkey  # key with index
                 tkey = sname
 
             # check if parameter key is present otherwise switch back to original name
@@ -321,16 +341,26 @@ class PulsarParametersPy(object):
         elif ptype == lalpulsar.PULSARTYPE_REAL8Vector_t:
             if not geterr:
                 if sidx is None:
-                    tmpvalue = lalpulsar.PulsarGetREAL8VectorParam(self._pulsarparameters, tkey)
-                    value = tmpvalue.data # 'data' in a REAL8Vector gets returned as a numpy array
+                    tmpvalue = lalpulsar.PulsarGetREAL8VectorParam(
+                        self._pulsarparameters, tkey
+                    )
+                    value = (
+                        tmpvalue.data
+                    )  # 'data' in a REAL8Vector gets returned as a numpy array
                 else:
-                    value = lalpulsar.PulsarGetREAL8VectorParamIndividual(self._pulsarparameters, indkey)
+                    value = lalpulsar.PulsarGetREAL8VectorParamIndividual(
+                        self._pulsarparameters, indkey
+                    )
             else:
                 if sidx is None:
-                    tmpvalue = lalpulsar.PulsarGetREAL8VectorParamErr(self._pulsarparameters, tkey)
+                    tmpvalue = lalpulsar.PulsarGetREAL8VectorParamErr(
+                        self._pulsarparameters, tkey
+                    )
                     value = tmpvalue.data
                 else:
-                    value = lalpulsar.PulsarGetREAL8VectorParamErrIndividual(self._pulsarparameters, indkey)
+                    value = lalpulsar.PulsarGetREAL8VectorParamErrIndividual(
+                        self._pulsarparameters, indkey
+                    )
         elif ptype == lalpulsar.PULSARTYPE_string_t:
             if not geterr:
                 value = lalpulsar.PulsarGetStringParam(self._pulsarparameters, tkey)
@@ -357,10 +387,10 @@ class PulsarParametersPy(object):
 
         if isinstance(value, float):
             lalpulsar.PulsarAddREAL8Param(self._pulsarparameters, key, value)
-        elif isinstance(value, string_types):
+        elif isinstance(value, str):
             lalpulsar.PulsarAddStringParam(self._pulsarparameters, key, value)
         elif isinstance(value, int):
-            if value < 0.: # store negative integers as floats
+            if value < 0.0:  # store negative integers as floats
                 lalpulsar.PulsarAddREAL8Param(self._pulsarparameters, key, float(value))
             else:
                 lalpulsar.PulsarAddUINT4Param(self._pulsarparameters, key, value)
@@ -388,7 +418,7 @@ class PulsarParametersPy(object):
                 list containing unit classes for a list or :class:`numpy.ndarray`
         """
 
-        if isinstance(value, string_types):
+        if isinstance(value, str):
             # don't make any changes for a string type
             return value
 
@@ -402,11 +432,11 @@ class PulsarParametersPy(object):
             cvalue = []
             bunit = ppunit
             for v in value:
-                cvalue.append(v*ppunit)
-                if uname in ['F', 'FB', 'P']: # frequency/period values
-                    ppunit *= bunit # increment unit (e.g. Hz -> Hz/s, Hz/s -> Hz/s^2)
+                cvalue.append(v * ppunit)
+                if uname in ["F", "FB", "P"]:  # frequency/period values
+                    ppunit *= bunit  # increment unit (e.g. Hz -> Hz/s, Hz/s -> Hz/s^2)
         else:
-            cvalue = value*ppunit
+            cvalue = value * ppunit
 
         return cvalue
 
@@ -430,21 +460,24 @@ class PulsarParametersPy(object):
         # for certain binary parameters there is an anomoly that their value
         # may have been rescaled (I think this is a hangover from a TEMPO definition compared to
         # the TEMPO2 definition)
-        binaryunits = ['XDOT', 'PBDOT', 'EPS1DOT', 'EPS2DOT', 'XPBDOT']
+        binaryunits = ["XDOT", "PBDOT", "EPS1DOT", "EPS2DOT", "XPBDOT"]
 
         # the names of epoch parameters that are held as GPS times, but must be converted back to
         # MJD for a TEMPO-style par file
-        epochpars = ['POSEPOCH',
-                     'PEPOCH',
-                     'WAVEEPOCH',
-                     'T0',
-                     'TASC',
-                     'T0_2',
-                     'T0_3',
-                     'START',
-                     'FINISH',
-                     'DMEPOCH',
-                     'GLEP']
+        epochpars = [
+            "POSEPOCH",
+            "PEPOCH",
+            "WAVEEPOCH",
+            "T0",
+            "TASC",
+            "T0_2",
+            "T0_3",
+            "START",
+            "FINISH",
+            "DMEPOCH",
+            "GLEP",
+            "TRANSIENTSTARTTIME",
+        ]
 
         uname = name.upper()
 
@@ -465,13 +498,13 @@ class PulsarParametersPy(object):
         if ppunit is None:
             if uname in binaryunits:
                 # for these binary parameters there is a TEMPO2 oddity that has to be corrected for
-                if abs(value)/1e-12 > 1e-7:
+                if abs(value) / 1e-12 > 1e-7:
                     value /= 1e-12
 
-            if isinstance(value, string_types):
+            if isinstance(value, str):
                 return value
             else:
-                return value*u.dimensionless_unscaled
+                return value * u.dimensionless_unscaled
 
         # convert to dimensionful value
         pvalue = self.convert_to_units(uname, value)
@@ -479,29 +512,31 @@ class PulsarParametersPy(object):
         if ppunit == tempounit or tempounit is None:
             tempounit = ppunit
 
-        if uname in ['RA', 'RAJ']:
+        if uname in ["RA", "RAJ"]:
             if not iserr:
                 # convert right ascension in radians into a string output format
-                c = ICRS(pvalue, 0.0*u.rad)
-                cvalue = c.ra.to_string(unit=tempounit, sep=':', precision=12, pad=True)
+                c = ICRS(pvalue, 0.0 * u.rad)
+                cvalue = c.ra.to_string(unit=tempounit, sep=":", precision=12, pad=True)
             else:
                 angle = Angle(pvalue)
-                cvalue = (angle.hms[0]*(60.**2) + angle.hms[1]*60. + angle.hms[2])*tempounit
-        elif uname in ['DEC', 'DECJ'] and not iserr:
-            c = ICRS(0.0*u.rad, pvalue)
-            cvalue = c.dec.to_string(unit=tempounit, sep=':', precision=12, pad=True)
+                cvalue = (
+                    angle.hms[0] * (60.0**2) + angle.hms[1] * 60.0 + angle.hms[2]
+                ) * tempounit
+        elif uname in ["DEC", "DECJ"] and not iserr:
+            c = ICRS(0.0 * u.rad, pvalue)
+            cvalue = c.dec.to_string(unit=tempounit, sep=":", precision=12, pad=True)
         elif uname in epochpars and not iserr:
             if isinstance(pvalue, list):
                 cvalue = []
                 for i, pv in enumerate(pvalue):
-                    t = Time(pv, format='gps', scale='tt')
-                    cvalue.append(t.mjd*tempounit)
+                    t = Time(pv, format="gps", scale="tt")
+                    cvalue.append(t.mjd * tempounit)
             else:
-                t = Time(pvalue, format='gps', scale='tt')
-                cvalue = t.mjd*tempounit
+                t = Time(pvalue, format="gps", scale="tt")
+                cvalue = t.mjd * tempounit
         elif uname in binaryunits and not iserr:
             # for these binary parameters there is a TEMPO2 oddity that has to be corrected for
-            if abs(pvalue.value)/1e-12 > 1e-7:
+            if abs(pvalue.value) / 1e-12 > 1e-7:
                 pvalue.value /= 1e-12
             cvalue = pvalue.to(tempounit)
         else:
@@ -511,8 +546,10 @@ class PulsarParametersPy(object):
                 bunit = tempounit
                 for i, pv in enumerate(pvalue):
                     cvalue.append(pv.to(tempounit))
-                    if uname in ['F', 'FB', 'P']: # frequency/period values
-                        tempounit *= bunit # increment unit (e.g. Hz -> Hz/s, Hz/s -> Hz/s^2)
+                    if uname in ["F", "FB", "P"]:  # frequency/period values
+                        tempounit *= (
+                            bunit  # increment unit (e.g. Hz -> Hz/s, Hz/s -> Hz/s^2)
+                        )
             else:
                 cvalue = pvalue.to(tempounit)
 
@@ -534,7 +571,7 @@ class PulsarParametersPy(object):
         if value is None:
             return None
 
-        if name.upper()[-4:] == '_ERR':
+        if name.upper()[-4:] == "_ERR":
             uname = name.upper()[:-4]
             iserr = True
         else:
@@ -556,14 +593,14 @@ class PulsarParametersPy(object):
         """
 
         thisitem = self._pulsarparameters.head
-        self.keynames = [] # clear any previous key names
+        self.keynames = []  # clear any previous key names
         self.length = 0
         while thisitem:
             tname = thisitem.name
             self.keynames.append(tname)
             self.length += 1
 
-            thisitem = thisitem.next # move on to next value
+            thisitem = thisitem.next  # move on to next value
 
         # reverse the order of the names, so they're in the same order as read from a par file
         self.keynames = self.keynames[::-1]
@@ -586,8 +623,12 @@ class PulsarParametersPy(object):
                 if ptype == lalpulsar.PULSARTYPE_REAL8_t:
                     value = lalpulsar.PulsarGetREAL8Param(self._pulsarparameters, key)
                 elif ptype == lalpulsar.PULSARTYPE_REAL8Vector_t:
-                    tmpvalue = lalpulsar.PulsarGetREAL8VectorParam(self._pulsarparameters, key)
-                    value = tmpvalue.data # 'data' in a REAL8Vector gets returned as a numpy array
+                    tmpvalue = lalpulsar.PulsarGetREAL8VectorParam(
+                        self._pulsarparameters, key
+                    )
+                    value = (
+                        tmpvalue.data
+                    )  # 'data' in a REAL8Vector gets returned as a numpy array
                 elif ptype == lalpulsar.PULSARTYPE_string_t:
                     value = lalpulsar.PulsarGetStringParam(self._pulsarparameters, key)
                 elif ptype == lalpulsar.PULSARTYPE_UINT4_t:
@@ -623,7 +664,7 @@ class PulsarParametersPy(object):
 
         titems = []
 
-        for (tk, tv) in zip(tkeys, tvalues):
+        for tk, tv in zip(tkeys, tvalues):
             titems.append((tk, tv))
 
         return titems
@@ -643,7 +684,9 @@ class PulsarParametersPy(object):
         pp = lalpulsar.ReadTEMPOParFile(filename)
 
         if pp is None:
-            raise IOError("Problem reading in pulsar parameter file '{}'".format(filename))
+            raise IOError(
+                "Problem reading in pulsar parameter file '{}'".format(filename)
+            )
 
         self._pulsarparameters = pp
 
@@ -656,10 +699,10 @@ class PulsarParametersPy(object):
         """
 
         try:
-            if name.upper()[-4:] == '_ERR':
+            if name.upper()[-4:] == "_ERR":
                 return self[name.upper()]
             else:
-                uname = name.upper() + '_ERR'
+                uname = name.upper() + "_ERR"
                 return self[uname]
         except ValueError:
             return None
@@ -674,7 +717,7 @@ class PulsarParametersPy(object):
         """
 
         if name.upper() not in self.keys():
-            return 0.
+            return 0.0
 
         fitflag = lalpulsar.PulsarGetParamFitFlagAsVector(self._pulsarparameters, name)
 
@@ -696,9 +739,13 @@ class PulsarParametersPy(object):
         """
 
         # output string format (set so that values should line up)
-        mkl = max([len(kn) for kn in self.keys()]) + 2  # max key length for output alignment
+        mkl = (
+            max([len(kn) for kn in self.keys()]) + 5
+        )  # max key length for output alignment
         vlb = precision + 10  # allow extra space for minus sign/exponents
-        outputstr = "{{name: <{0}}}{{value: <{1}}}{{fitflag}}\t{{error}}".format(mkl, vlb)
+        outputstr = "{{name: <{0}}}{{value: <{1}}}{{fitflag}}\t{{error}}".format(
+            mkl, vlb
+        )
 
         parstr = ""
 
@@ -729,7 +776,7 @@ class PulsarParametersPy(object):
                     for tv, te in zip(uvalue, uevalue):
                         tvalue.append(tv.value)
                         tevalue.append(te.value)
-                elif isinstance(uvalue, string_types):
+                elif isinstance(uvalue, str):
                     tvalue = uvalue
                     tevalue = uevalue.value
                 else:
@@ -748,7 +795,17 @@ class PulsarParametersPy(object):
             if isinstance(tvalue, list) or isinstance(tvalue, np.ndarray):
                 idxoffset = 0
                 idxsep = ""
-                if key in ['WAVESIN', 'WAVECOS', 'GLEP', 'GLPH', 'GLF0', 'GLF1', 'GLF2', 'GLF0D', 'GLTD']:
+                if key in [
+                    "WAVESIN",
+                    "WAVECOS",
+                    "GLEP",
+                    "GLPH",
+                    "GLF0",
+                    "GLF1",
+                    "GLF2",
+                    "GLF0D",
+                    "GLTD",
+                ]:
                     # the TEMPO variable name for these parameter start with an index a 1
                     idxoffset = 1
 
@@ -768,22 +825,21 @@ class PulsarParametersPy(object):
                         wavecos = tvalue
 
                     for ws, wc in zip(wavesin, wavecos):
-                        precstrs = '{{0:.{}f}}'.format(precision)  # print out float
+                        precstrs = "{{0:.{}f}}".format(precision)  # print out float
                         if ws < 1e-6 or ws > 1e6:
                             # print out float in scientific notation
-                            precstrs = '{{0:.{}e}}'.format(precision)
+                            precstrs = "{{0:.{}e}}".format(precision)
 
-                        precstrc = '{{0:.{}f}}'.format(precision)  # print out float
+                        precstrc = "{{0:.{}f}}".format(precision)  # print out float
                         if wc < 1e-6 or wc > 1e6:
                             # print out float in scientific notation
-                            precstrc = '{{0:.{}e}}'.format(precision)
+                            precstrc = "{{0:.{}e}}".format(precision)
 
                         outputdic = {}
                         outputdic["name"] = "WAVE{}{}".format(idxsep, idxoffset)
                         idxoffset += 1
                         outputdic["value"] = "{}\t{}".format(
-                            precstrs.format(ws),
-                            precstrc.format(wc)
+                            precstrs.format(ws), precstrc.format(wc)
                         )
                         outputdic["fitflag"] = ""
                         outputdic["error"] = ""
@@ -791,57 +847,57 @@ class PulsarParametersPy(object):
                         parstr += outputstr.format(**outputdic).strip() + "\n"
                 else:
                     for tv, te, tf in zip(tvalue, tevalue, fitflag):
-                        precstr = '{{0:.{}f}}'.format(precision) # print out float
+                        precstr = "{{0:.{}f}}".format(precision)  # print out float
                         if tv < 1e-6 or tv > 1e6:
                             # print out float in scientific notation
-                            precstr = '{{0:.{}e}}'.format(precision)
+                            precstr = "{{0:.{}e}}".format(precision)
 
-                        precstre = '{{0:.{}f}}'.format(precision) # print out float
+                        precstre = "{{0:.{}f}}".format(precision)  # print out float
                         if te < 1e-6 or te > 1e6:
                             # print out float in scientific notation
-                            precstre = '{{0:.{}e}}'.format(precision)
+                            precstre = "{{0:.{}e}}".format(precision)
 
                         outputdic = {}
-                        outputdic['name'] = '{}{}{}'.format(key, idxsep, idxoffset)
+                        outputdic["name"] = "{}{}{}".format(key, idxsep, idxoffset)
                         idxoffset += 1
-                        outputdic['value'] = precstr.format(tv)
-                        outputdic['fitflag'] = '1' if tf == 1 else ''
-                        outputdic['error'] = precstre.format(te) if te != 0. else ''
+                        outputdic["value"] = precstr.format(tv)
+                        outputdic["fitflag"] = "1" if tf == 1 else ""
+                        outputdic["error"] = precstre.format(te) if te != 0.0 else ""
 
                         parstr += outputstr.format(**outputdic).strip() + "\n"
             else:
-                if isinstance(tvalue, float) or key in ['RA', 'RAJ', 'DEC', 'DECJ']:
+                if isinstance(tvalue, float) or key in ["RA", "RAJ", "DEC", "DECJ"]:
                     if isinstance(tvalue, float):
-                        precstr = '{{0:.{}f}}'.format(precision) # print out float
+                        precstr = "{{0:.{}f}}".format(precision)  # print out float
                         if tvalue < 1e-6 or tvalue > 1e6:
                             # print out float in scientific notation
-                            precstr = '{{0:.{}e}}'.format(precision)
+                            precstr = "{{0:.{}e}}".format(precision)
 
                         ovalue = precstr.format(tvalue)
                     else:
                         ovalue = tvalue
 
-                    precstre = '{{0:.{}f}}'.format(precision) # print out float
-                    oevalue = ''
+                    precstre = "{{0:.{}f}}".format(precision)  # print out float
+                    oevalue = ""
                     if tevalue is not None:
-                        if tevalue != 0.:
+                        if tevalue != 0.0:
                             if tevalue < 1e-6 or tevalue > 1e6:
                                 # print out float in scientific notation
-                                precstre = '{{0:.{}e}}'.format(precision)
+                                precstre = "{{0:.{}e}}".format(precision)
 
                             oevalue = precstre.format(tevalue)
 
                             if fitflag is not None:
                                 if fitflag == 1:
-                                    ofitflag = '1'
+                                    ofitflag = "1"
                 else:
                     ovalue = tvalue
 
                 outputdic = {}
-                outputdic['name'] = key
-                outputdic['value'] = ovalue
-                outputdic['fitflag'] = ofitflag
-                outputdic['error'] = oevalue
+                outputdic["name"] = key
+                outputdic["value"] = ovalue
+                outputdic["fitflag"] = ofitflag
+                outputdic["error"] = oevalue
 
                 parstr += outputstr.format(**outputdic).strip() + "\n"
 
@@ -857,7 +913,7 @@ class PulsarParametersPy(object):
         """
 
         try:
-            fp = open(filename, 'w')
+            fp = open(filename, "w")
         except IOError:
             raise IOError("Could not open file '{}' for writing".format(filename))
 
