@@ -16,7 +16,7 @@
 
 ## \defgroup lalpulsar_py_simulateCW SimulateCW
 ## \ingroup lalpulsar_python
-"""
+r"""
 Generate strain time series of a continuous-wave signal in the detector frame,
 given a function which computes signal phase and amplitudes as functions of time.
 
@@ -72,9 +72,10 @@ for file, i, N in S.write_frame_files(fs=1, Tframe=1800, comment="simCW"):
 """
 ## @{
 
-from __future__ import (division, print_function)
+from __future__ import division, print_function
 
 import os
+import sys
 import re
 import math
 
@@ -89,9 +90,23 @@ __date__ = git_version.date
 
 
 class CWSimulator(object):
-
-    def __init__(self, tref, tstart, Tdata, waveform, dt_wf, phi0, psi, alpha, delta, det_name,
-                 earth_ephem_file="earth00-19-DE405.dat.gz", sun_ephem_file="sun00-19-DE405.dat.gz", tref_at_det=False, extra_comment=None):
+    def __init__(
+        self,
+        tref,
+        tstart,
+        Tdata,
+        waveform,
+        dt_wf,
+        phi0,
+        psi,
+        alpha,
+        delta,
+        det_name,
+        earth_ephem_file="earth00-40-DE405.dat.gz",
+        sun_ephem_file="sun00-40-DE405.dat.gz",
+        tref_at_det=False,
+        extra_comment=None,
+    ):
         """
         Initialise a continuous-wave signal simulator.
 
@@ -123,9 +138,14 @@ class CWSimulator(object):
                (not filenames), e.g. for wrapper script commandlines
         """
 
-        self.__origin_str = "Generated by %s, %s-%s (%s)" % (__file__, git_version.id, git_version.status, git_version.date)
+        self.__origin_str = "Generated by %s, %s-%s (%s)" % (
+            __file__,
+            git_version.id,
+            git_version.status,
+            git_version.date,
+        )
         if extra_comment:
-            self.__origin_str += ", "+extra_comment
+            self.__origin_str += ", " + extra_comment
 
         # store arguments
         self.__tstart = tstart
@@ -134,7 +154,7 @@ class CWSimulator(object):
         # parse detector name
         try:
             _, self.__site_index = lalpulsar.FindCWDetector(det_name, True)
-            assert(self.__site_index >= 0)
+            assert self.__site_index >= 0
         except:
             raise ValueError("Invalid detector name det_name='%s'" % det_name)
         self.__site = lal.CachedDetectors[self.__site_index]
@@ -143,7 +163,6 @@ class CWSimulator(object):
         self.__ephemerides = lalpulsar.InitBarycenter(earth_ephem_file, sun_ephem_file)
 
         if tref_at_det:
-
             # calculate barycentric delay at reference time
             bary_state = lalpulsar.EarthState()
             bary_input = lalpulsar.BarycenterInput()
@@ -167,10 +186,12 @@ class CWSimulator(object):
         # you run with LAL_DEBUG_LEVEL=warning)
         Tpad_wf = 2.0 * lal.AU_SI / lal.C_SI
         tstart_wf = tstart - Tpad_wf
-        Nwf = int(math.ceil(float(Tdata + 2*Tpad_wf) / float(dt_wf)))
+        Nwf = int(math.ceil(float(Tdata + 2 * Tpad_wf) / float(dt_wf)))
 
         # create REAL8TimeSeries to store signal phase
-        self.__phi = lal.CreateREAL8TimeSeries("phi", tstart_wf, 0, dt_wf, lal.DimensionlessUnit, Nwf)
+        self.__phi = lal.CreateREAL8TimeSeries(
+            "phi", tstart_wf, 0, dt_wf, lal.DimensionlessUnit, Nwf
+        )
 
         # create REAL4TimeVectorSeries to store signal amplitudes
         # - LAL provides no creator function for this type, so must be done manually
@@ -206,16 +227,17 @@ class CWSimulator(object):
         self.__detector.ephemerides = self.__ephemerides
 
     def _simulate_coherent_gw(self, h, noise_sqrt_Sh, noise_seed):
-
         # generate strain time series
         lalpulsar.PulsarSimulateCoherentGW(h, self.__wf, self.__detector)
 
         # add Gaussian noise, if requested
         if noise_sqrt_Sh > 0:
+            assert noise_seed is not None
+            assert noise_seed > 0
             noise_sigma = math.sqrt(0.5 / h.deltaT) * noise_sqrt_Sh
             lalpulsar.AddGaussianNoise(h, noise_sigma, noise_seed)
 
-    def get_strain(self, fs, tmin=0, tmax=None, noise_sqrt_Sh=0, noise_seed=0):
+    def get_strain(self, fs, tmin=0, tmax=None, noise_sqrt_Sh=0, noise_seed=None):
         """
         Generate strain time series of a continuous-wave signal in the detector frame.
 
@@ -224,7 +246,8 @@ class CWSimulator(object):
         @param tmax: start time for strain time series, as offsets from self.__tstart
         @param noise_sqrt_Sh: if >0, add Gaussian noise with square-root single-sided power
             spectral density given by this value, in Hz^(-1/2)
-        @param noise_seed: use this need for the random number generator used to create noise
+        @param noise_seed: use this seed for the random number generator used to create noise;
+            required if noise_sqrt_Sh >0
 
         @return (@b t, @b h), where:
             @b t = start of time strain time series, in GPS seconds;
@@ -232,24 +255,27 @@ class CWSimulator(object):
         """
 
         # process tmin/tmax range (interpreted relative to self.__tstart)
-        if (tmin < 0) or (tmin>=self.__Tdata):
-            raise ValueError('tmin must be within [0,{}).'.format(self.__Tdata))
+        if (tmin < 0) or (tmin >= self.__Tdata):
+            raise ValueError("tmin must be within [0,{}).".format(self.__Tdata))
         if tmax is None:
             tmax = self.__Tdata
-        elif (tmax <= 0) or (tmax>self.__Tdata):
-            raise ValueError('tmax must be within (0,{}].'.format(self.__Tdata))
-        tspan = tmax-tmin
+        elif (tmax <= 0) or (tmax > self.__Tdata):
+            raise ValueError("tmax must be within (0,{}].".format(self.__Tdata))
+        tspan = tmax - tmin
 
         # create REAL4TimeSeries to store output time series
-        Nh = int(fs*tspan)
-        h = lal.CreateREAL4TimeSeries("h", self.__tstart+tmin, 0, 1.0 / fs,
-                                      lal.DimensionlessUnit, Nh)
+        Nh = int(fs * tspan)
+        h = lal.CreateREAL4TimeSeries(
+            "h", self.__tstart + tmin, 0, 1.0 / fs, lal.DimensionlessUnit, Nh
+        )
 
         # generate strain time series
         self._simulate_coherent_gw(h, noise_sqrt_Sh, noise_seed)
         return (h.epoch, h.data.data)
 
-    def get_strain_blocks(self, fs, Tblock, noise_sqrt_Sh=0, noise_seed=0):
+    def get_strain_blocks(
+        self, fs, Tblock, noise_sqrt_Sh=0, noise_seed=None, prog_bar=None
+    ):
         """
         Generate strain time series of a continuous-wave signal in the detector frame, in contiguous blocks.
 
@@ -257,7 +283,9 @@ class CWSimulator(object):
         @param Tblock: length of each block, in seconds; should divide evenly into @b Tdata
         @param noise_sqrt_Sh: if >0, add Gaussian noise with square-root single-sided power
             spectral density given by this value, in Hz^(-1/2)
-        @param noise_seed: use this need for the random number generator used to create noise
+        @param noise_seed: use this seed for the random number generator used to create noise;
+            if None, generate a random seed using os.urandom()
+        @param prog_bar: use to display a progress bar, e.g. prog_bar=tqdm
 
         @return (@b t, @b h, @b i, @b N), where:
             @b t = start of time strain time series, in GPS seconds;
@@ -276,18 +304,47 @@ class CWSimulator(object):
         # work out number of blocks
         Nblock = int(round(self.__Tdata / Tblock))
         if Tblock * Nblock > self.__Tdata:
-            raise ValueError("Length of block Tblock=%g does not divide evenly into Tdata=%g" % (Tblock, self.__Tdata))
+            raise ValueError(
+                "Length of block Tblock=%g does not divide evenly into Tdata=%g"
+                % (Tblock, self.__Tdata)
+            )
+
+        # if no noise seed is given, generate a (non-zero) random seed using os.urandom()
+        if not noise_seed:
+            noise_seed = 0
+            while not (0 < noise_seed and noise_seed < lal.LAL_INT4_MAX - Nblock):
+                noise_seed = int.from_bytes(os.urandom(4), sys.byteorder, signed=False)
+
+        # iterate over blocks
+        blocks = range(0, Nblock)
+        if prog_bar is not None:
+
+            # wrap iterator in progress bar
+            blocks = prog_bar(blocks)
 
         # generate strain time series in blocks of length 'Tblock'
         tmin = 0
-        for iblock in range(0, Nblock):
-            epoch, hoft = self.get_strain(fs, tmin=tmin, tmax=tmin+Tblock,
-                                          noise_sqrt_Sh=noise_sqrt_Sh,
-                                          noise_seed=noise_seed + iblock)
+        for iblock in blocks:
+            epoch, hoft = self.get_strain(
+                fs,
+                tmin=tmin,
+                tmax=tmin + Tblock,
+                noise_sqrt_Sh=noise_sqrt_Sh,
+                noise_seed=noise_seed + iblock,
+            )
             yield epoch, hoft, iblock, Nblock
             tmin += Tblock
 
-    def write_frame_files(self, fs, Tframe, comment, out_dir=".", noise_sqrt_Sh=0, noise_seed=0):
+    def write_frame_files(
+        self,
+        fs,
+        Tframe,
+        comment="simCW",
+        out_dir=".",
+        noise_sqrt_Sh=0,
+        noise_seed=None,
+        prog_bar=None,
+    ):
         """
         Write frame files [1] containing strain time series of a continuous-wave signal.
 
@@ -302,7 +359,9 @@ class CWSimulator(object):
         @param out_dir: output directory to write frame files into
         @param noise_sqrt_Sh: if >0, add Gaussian noise with square-root single-sided power
             spectral density given by this value, in Hz^(-1/2)
-        @param noise_seed: use this need for the random number generator used to create noise
+        @param noise_seed: use this seed for the random number generator used to create noise;
+            if None, generate a random seed using os.urandom()
+        @param prog_bar: use to display a progress bar, e.g. prog_bar=tqdm
 
         @return (@b file, @b i, @b N), where:
             @b file = name of frame file just written;
@@ -325,32 +384,49 @@ class CWSimulator(object):
             raise ImportError("SWIG wrappings of LALFrame cannot be imported")
 
         # check for valid frame filename comment (see LIGO-T010150)
-        valid_comment = re.compile(r'^[A-Za-z0-9_+#]+$')
+        valid_comment = re.compile(r"^[A-Za-z0-9_+#]+$")
         if not valid_comment.match(comment):
-            raise ValueError("Frame file comment='%s' may only contain A-Z, a-z, 0-9, _, +, # characters" % comment)
+            raise ValueError(
+                "Frame file comment='%s' may only contain A-Z, a-z, 0-9, _, +, # characters"
+                % comment
+            )
 
         # generate strain time series in blocks of length 'Tframe'
         frame_h = None
-        for t, h, i, N in self.get_strain_blocks(fs, Tframe, noise_sqrt_Sh=noise_sqrt_Sh, noise_seed=noise_seed):
-
+        for t, h, i, N in self.get_strain_blocks(
+            fs,
+            Tframe,
+            noise_sqrt_Sh=noise_sqrt_Sh,
+            noise_seed=noise_seed,
+            prog_bar=prog_bar,
+        ):
             # create and initialise REAL8TimeSeries to write to frame files
             if frame_h is None:
-                frame_h_channel = '%s:SIMCW-STRAIN' % self.__site.frDetector.prefix
-                frame_h = lal.CreateREAL8TimeSeries(frame_h_channel, t, 0, 1.0 / fs, lal.DimensionlessUnit, len(h))
+                frame_h_channel = "%s:SIMCW-STRAIN" % self.__site.frDetector.prefix
+                frame_h = lal.CreateREAL8TimeSeries(
+                    frame_h_channel, t, 0, 1.0 / fs, lal.DimensionlessUnit, len(h)
+                )
             frame_h.epoch = t
             frame_h.data.data = h
 
             # create standard frame file name (see LIGO-T010150)
             frame_src = self.__site.frDetector.prefix[0]
-            frame_desc = 'simCW_%s' % comment
+            frame_desc = comment
             frame_t0 = int(t.gpsSeconds)
             frame_Tdata = int(math.ceil(float(t + Tframe)) - math.floor(float(t)))
-            frame_name = '%s-%s-%u-%u.gwf' % (frame_src, frame_desc, frame_t0, frame_Tdata)
+            frame_name = "%s-%s-%u-%u.gwf" % (
+                frame_src,
+                frame_desc,
+                frame_t0,
+                frame_Tdata,
+            )
             frame_path = os.path.join(out_dir, frame_name)
 
             # create frame
             frame_det_bits = 2 * self.__site_index
-            frame = lalframe.FrameNew(t, Tframe, "simCW", -1, i, frame_det_bits)
+            frame = lalframe.FrameNew(
+                t, Tframe, self.__class__.__name__, -1, i, frame_det_bits
+            )
 
             # add strain time series to frame
             lalframe.FrameAddREAL8TimeSeriesProcData(frame, frame_h)
@@ -364,7 +440,16 @@ class CWSimulator(object):
             # yield current file name for e.g. printing progress
             yield frame_path, i, N
 
-    def get_sfts(self, fmax, Tsft, noise_sqrt_Sh=0, noise_seed=0, window=None, window_param=0):
+    def get_sfts(
+        self,
+        fmax,
+        Tsft,
+        noise_sqrt_Sh=0,
+        noise_seed=None,
+        window="rectangular",
+        window_param=0,
+        prog_bar=None,
+    ):
         """
         Generate SFTs [2] containing strain time series of a continuous-wave signal.
 
@@ -372,10 +457,12 @@ class CWSimulator(object):
         @param Tsft: length of each SFT, in seconds; should divide evenly into @b Tdata
         @param noise_sqrt_Sh: if >0, add Gaussian noise with square-root single-sided power
             spectral density given by this value, in Hz^(-1/2)
-        @param noise_seed: use this need for the random number generator used to create noise
+        @param noise_seed: use this seed for the random number generator used to create noise;
+            if None, generate a random seed using os.urandom()
         @param window: if not None, window the time series before performing the FFT, using
             the named window function; see XLALCreateNamedREAL8Window()
         @param window_param: parameter for the window function given by @b window, if needed
+        @param prog_bar: use to display a progress bar, e.g. prog_bar=tqdm
 
         @return (@b sft, @b i, @b N), where:
             @b sft = SFT;
@@ -399,36 +486,58 @@ class CWSimulator(object):
         # generate strain time series in blocks of length 'Tsft'
         sft_h = None
         sft_fs = 2 * fmax
-        for t, h, i, N in self.get_strain_blocks(sft_fs, Tsft, noise_sqrt_Sh=noise_sqrt_Sh, noise_seed=noise_seed):
-
+        for t, h, i, N in self.get_strain_blocks(
+            sft_fs,
+            Tsft,
+            noise_sqrt_Sh=noise_sqrt_Sh,
+            noise_seed=noise_seed,
+            prog_bar=prog_bar,
+        ):
             # create and initialise REAL8TimeSeries to write to SFT files
             if sft_h is None:
                 sft_name = self.__site.frDetector.prefix
-                sft_h = lal.CreateREAL8TimeSeries(sft_name, t, 0, 1.0 / sft_fs, lal.DimensionlessUnit, len(h))
+                sft_h = lal.CreateREAL8TimeSeries(
+                    sft_name, t, 0, 1.0 / sft_fs, lal.DimensionlessUnit, len(h)
+                )
             sft_h.epoch = t
             sft_h.data.data = h
 
             # create SFT, possibly with windowing
             sft_ts.data[0] = t
-            sft_vect = lalpulsar.MakeSFTsFromREAL8TimeSeries(sft_h, sft_ts, window, window_param)
+            sft_vect = lalpulsar.MakeSFTsFromREAL8TimeSeries(
+                sft_h, sft_ts, window, window_param
+            )
 
             # yield current SFT
             yield sft_vect.data[0], i, N
 
-    def write_sft_files(self, fmax, Tsft, comment, out_dir=".", noise_sqrt_Sh=0, noise_seed=0, window=None, window_param=0):
+    def write_sft_files(
+        self,
+        fmax,
+        Tsft,
+        comment="simCW",
+        out_dir=".",
+        noise_sqrt_Sh=0,
+        noise_seed=None,
+        window="rectangular",
+        window_param=0,
+        prog_bar=None,
+    ):
         """
         Write SFT files [2] containing strain time series of a continuous-wave signal.
 
         @param fmax: maximum SFT frequency, in Hz
         @param Tsft: length of each SFT, in seconds; should divide evenly into @b Tdata
-        @param comment: SFT file name comment, may only contain A-Z, a-z, 0-9, _, +, # characters
+        @param comment: SFT file name comment, may only contain A-Z, a-z, 0-9 characters
         @param out_dir: output directory to write SFT files into
         @param noise_sqrt_Sh: if >0, add Gaussian noise with square-root single-sided power
             spectral density given by this value, in Hz^(-1/2)
-        @param noise_seed: use this need for the random number generator used to create noise
+        @param noise_seed: use this seed for the random number generator used to create noise;
+            if None, generate a random seed using os.urandom()
         @param window: if not None, window the time series before performing the FFT, using
             the named window function; see XLALCreateNamedREAL8Window()
         @param window_param: parameter for the window function given by @b window, if needed
+        @param prog_bar: use to display a progress bar, e.g. prog_bar=tqdm
 
         @return (@b file, @b i, @b N), where:
             @b file = name of SFT file just written;
@@ -446,22 +555,36 @@ class CWSimulator(object):
         """
 
         # check for valid SFT filename comment (see LIGO-T040164)
-        valid_comment = re.compile(r'^[A-Za-z0-9_+#]+$')
+        valid_comment = re.compile(r"^[A-Za-z0-9]+$")
         if not valid_comment.match(comment):
-            raise ValueError("SFT file comment='%s' may only contain A-Z, a-z, 0-9, _, +, # characters" % comment)
+            raise ValueError(
+                "SFT file comment='%s' may only contain A-Z, a-z, 0-9 characters"
+                % comment
+            )
+
+        # create SFT filename specification
+        spec = lalpulsar.SFTFilenameSpec()
+        spec.path = out_dir
+        spec.window_type = window
+        spec.window_param = window_param
+        spec.privMisc = comment
 
         # generate SFTs
-        for sft, i, N in self.get_sfts(fmax, Tsft, noise_sqrt_Sh=noise_sqrt_Sh, noise_seed=noise_seed, window=window, window_param=window_param):
-
-            # create standard SFT file name (see LIGO-T040164)
-            sft_desc = 'simCW_%s' % comment
-            sft_name = lalpulsar.GetOfficialName4SFT(sft, sft_desc)
-            sft_path = os.path.join(out_dir, sft_name)
-
+        for sft, i, N in self.get_sfts(
+            fmax,
+            Tsft,
+            noise_sqrt_Sh=noise_sqrt_Sh,
+            noise_seed=noise_seed,
+            window=window,
+            window_param=window_param,
+            prog_bar=prog_bar,
+        ):
             # write SFT
-            lalpulsar.WriteSFT2file(sft, sft_path, self.__origin_str)
+            lalpulsar.WriteSFT2StandardFile(sft, spec, self.__origin_str)
 
             # yield current file name for e.g. printing progress
+            sft_path = lalpulsar.BuildSFTFilenameFromSpec(spec)
             yield sft_path, i, N
 
+
 ## @}
