@@ -13,8 +13,8 @@
 *
 *  You should have received a copy of the GNU General Public License
 *  along with with program; see the file COPYING. If not, write to the
-*  Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-*  MA  02111-1307  USA
+*  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+*  MA  02110-1301  USA
 */
 
 /*-----------------------------------------------------------------------
@@ -156,7 +156,8 @@ typedef CHAR HoughDT;
 
 /* >>>>>>>>>>>>>>>>>>>>>>>>>>>>>>><<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<< */
 /* vvvvvvvvvvvvvvvvvvvvvvvvvvvvvv------------------------------------ */
-int main(int argc, char *argv[]){
+int main( int argc, char *argv[] )
+{
 
   static LALStatus       status;  /* LALStatus pointer */
   static HOUGHptfLUT     lut;     /* the Look Up Table */
@@ -180,10 +181,10 @@ int main(int argc, char *argv[]){
   HoughDT *pointer;
 
   CHAR *fname = NULL;               /* The output filename */
-  FILE *fp=NULL;                    /* Output file */
+  FILE *fp = NULL;                  /* Output file */
 
   INT4 arg;                         /* Argument counter */
-  INT4 i,j,k,binPoint;              /* Index counter, etc */
+  INT4 i, j, k, binPoint;           /* Index counter, etc */
   REAL8 f0, alpha, delta, veloMod;
   REAL8 patchSizeX, patchSizeY;
 
@@ -192,12 +193,12 @@ int main(int argc, char *argv[]){
   /************************************************************/
 
   f0 =  F0;
-  f0Bin = F0*TCOH;
+  f0Bin = F0 * TCOH;
 
   parRes.f0Bin =  f0Bin;
   parRes.deltaF = DF;
-  parRes.patchSkySizeX  = patchSizeX = 1.0/(TCOH*F0*VEPI);
-  parRes.patchSkySizeY  = patchSizeY = 1.0/(TCOH*F0*VEPI);
+  parRes.patchSkySizeX  = patchSizeX = 1.0 / ( TCOH * F0 * VEPI );
+  parRes.patchSkySizeY  = patchSizeY = 1.0 / ( TCOH * F0 * VEPI );
   parRes.pixelFactor = PIXELFACTOR;
   parRes.pixErr = PIXERR;
   parRes.linErr = LINERR;
@@ -242,8 +243,8 @@ int main(int argc, char *argv[]){
     else if ( !strcmp( argv[arg], "-f" ) ) {
       if ( argc > arg + 1 ) {
         arg++;
-	f0 = atof(argv[arg++]);
-	f0Bin = f0*TCOH;
+        f0 = atof( argv[arg++] );
+        f0Bin = f0 * TCOH;
         parRes.f0Bin =  f0Bin;
       } else {
         ERROR( TESTCONSTRUCTPLUTC_EARG, TESTCONSTRUCTPLUTC_MSGEARG, 0 );
@@ -255,20 +256,20 @@ int main(int argc, char *argv[]){
     else if ( !strcmp( argv[arg], "-p" ) ) {
       if ( argc > arg + 2 ) {
         arg++;
-	alpha = atof(argv[arg++]);
-	delta = atof(argv[arg++]);
+        alpha = atof( argv[arg++] );
+        delta = atof( argv[arg++] );
       } else {
         ERROR( TESTCONSTRUCTPLUTC_EARG, TESTCONSTRUCTPLUTC_MSGEARG, 0 );
         XLALPrintError( USAGE, *argv );
         return TESTCONSTRUCTPLUTC_EARG;
       }
     }
-     /* Parse patch size option. */
+    /* Parse patch size option. */
     else if ( !strcmp( argv[arg], "-s" ) ) {
       if ( argc > arg + 2 ) {
         arg++;
-	parRes.patchSkySizeX = patchSizeX = atof(argv[arg++]);
-        parRes.patchSkySizeY = patchSizeY = atof(argv[arg++]);
+        parRes.patchSkySizeX = patchSizeX = atof( argv[arg++] );
+        parRes.patchSkySizeY = patchSizeY = atof( argv[arg++] );
       } else {
         ERROR( TESTCONSTRUCTPLUTC_EARG, TESTCONSTRUCTPLUTC_MSGEARG, 0 );
         XLALPrintError( USAGE, *argv );
@@ -286,7 +287,7 @@ int main(int argc, char *argv[]){
 
   if ( f0 < 0 ) {
     ERROR( TESTCONSTRUCTPLUTC_EBAD, TESTCONSTRUCTPLUTC_MSGEBAD, "freq<0:" );
-    XLALPrintError( USAGE, *argv  );
+    XLALPrintError( USAGE, *argv );
     return TESTCONSTRUCTPLUTC_EBAD;
   }
 
@@ -307,8 +308,8 @@ int main(int argc, char *argv[]){
 
   patch.xCoor = NULL;
   patch.yCoor = NULL;
-  patch.xCoor = (REAL8 *)LALMalloc(xSide*sizeof(REAL8));
-  patch.yCoor = (REAL8 *)LALMalloc(ySide*sizeof(REAL8));
+  patch.xCoor = ( REAL8 * )LALMalloc( xSide * sizeof( REAL8 ) );
+  patch.yCoor = ( REAL8 * )LALMalloc( ySide * sizeof( REAL8 ) );
 
   SUB( LALHOUGHFillPatchGrid( &status, &patch, &parSize ), &status );
 
@@ -319,15 +320,15 @@ int main(int argc, char *argv[]){
   lut.maxNBins = maxNBins;
   lut.maxNBorders = maxNBorders;
   lut.border =
-    (HOUGHBorder *)LALMalloc(maxNBorders*sizeof(HOUGHBorder));
+    ( HOUGHBorder * )LALMalloc( maxNBorders * sizeof( HOUGHBorder ) );
   lut.bin =
-    (HOUGHBin2Border *)LALMalloc(maxNBins*sizeof(HOUGHBin2Border));
+    ( HOUGHBin2Border * )LALMalloc( maxNBins * sizeof( HOUGHBin2Border ) );
 
-  PHMD = (HoughDT *)LALMalloc((xSide+1)*ySide*sizeof(HoughDT));
+  PHMD = ( HoughDT * )LALMalloc( ( xSide + 1 ) * ySide * sizeof( HoughDT ) );
 
-  for (i=0; i < maxNBorders; ++i){
+  for ( i = 0; i < maxNBorders; ++i ) {
     lut.border[i].ySide = ySide;
-    lut.border[i].xPixel = (COORType *)LALMalloc(ySide*sizeof(COORType));
+    lut.border[i].xPixel = ( COORType * )LALMalloc( ySide * sizeof( COORType ) );
   }
 
 
@@ -335,9 +336,9 @@ int main(int argc, char *argv[]){
   /* Case: no spins, patch at south pole   */
   /******************************************************************/
 
-  parDem.veloC.x = veloMod*cos(delta)*cos(alpha);
-  parDem.veloC.y = veloMod*cos(delta)*sin(alpha);
-  parDem.veloC.z = veloMod*sin(delta);
+  parDem.veloC.x = veloMod * cos( delta ) * cos( alpha );
+  parDem.veloC.y = veloMod * cos( delta ) * sin( alpha );
+  parDem.veloC.z = veloMod * sin( delta );
 
   parDem.positC.x = 0.0;
   parDem.positC.y = 0.0;
@@ -361,34 +362,36 @@ int main(int argc, char *argv[]){
   /*******************************************************/
 
   /* initializing output  space */
-  pointer = &( PHMD[0]);
-  for ( k=0; k< (xSide+1)*ySide; ++k ){
+  pointer = &( PHMD[0] );
+  for ( k = 0; k < ( xSide + 1 )*ySide; ++k ) {
     *pointer = 0;
     ++pointer;
   }
 
   binPoint = lut.iniBin + lut.nBin;
 
-   /* just as a test examples */
+  /* just as a test examples */
 
-  for( k= lut.iniBin; k < binPoint ; k+=2 ){
-  /* this should be for plotting each two bins!
-     so one can see all border with +1 or -1 */
+  for ( k = lut.iniBin; k < binPoint ; k += 2 ) {
+    /* this should be for plotting each two bins!
+       so one can see all border with +1 or -1 */
 
-  /* for( k= -2; k < 3 ; k+=2 ){ */
-        /* now just 3 peaks selected -2,0,+2 */
+    /* for( k= -2; k < 3 ; k+=2 ){ */
+    /* now just 3 peaks selected -2,0,+2 */
 
 
-    INT2 lb1,rb1,lb2,rb2; /* The border index. If zero means that */
-        /* it does not intersect the patch, or nothing to clip */
-    INT2 max1,min1,max2,min2;
+    INT2 lb1, rb1, lb2, rb2; /* The border index. If zero means that */
+    /* it does not intersect the patch, or nothing to clip */
+    INT2 max1, min1, max2, min2;
     INT2 xindex;
 
     /* conversion of "peak index" (separation to the f0 frequency)
        into the bin in the LUT */
 
     i = k;
-    if( k < 0) i = binPoint -1-k;
+    if ( k < 0 ) {
+      i = binPoint - 1 - k;
+    }
 
     /*reading the bin information */
 
@@ -403,41 +406,45 @@ int main(int argc, char *argv[]){
     min2 = lut.bin[i].piece2min;
 
     /* drawing the annuli borders */
-    if(lb1){
-      for(j = lut.border[lb1].yLower;
-	  j <= lut.border[lb1].yUpper; j++ ){
-	xindex =  lut.border[lb1].xPixel[j];
-	PHMD[j*(xSide+1) + xindex] += 1;
+    if ( lb1 ) {
+      for ( j = lut.border[lb1].yLower;
+            j <= lut.border[lb1].yUpper; j++ ) {
+        xindex =  lut.border[lb1].xPixel[j];
+        PHMD[j * ( xSide + 1 ) + xindex] += 1;
       }
     }
-    if(lb2){
-      for(j = lut.border[lb2].yLower;
-	  j <= lut.border[lb2].yUpper; j++ ){
-	xindex =  lut.border[lb2].xPixel[j];
-	PHMD[j*(xSide+1) + xindex] += 1;
+    if ( lb2 ) {
+      for ( j = lut.border[lb2].yLower;
+            j <= lut.border[lb2].yUpper; j++ ) {
+        xindex =  lut.border[lb2].xPixel[j];
+        PHMD[j * ( xSide + 1 ) + xindex] += 1;
       }
     }
-    if(rb1){
-      for(j = lut.border[rb1].yLower;
-	  j <= lut.border[rb1].yUpper; j++ ){
-	xindex =  lut.border[rb1].xPixel[j];
-	PHMD[j*(xSide+1) + xindex] -= 1;
+    if ( rb1 ) {
+      for ( j = lut.border[rb1].yLower;
+            j <= lut.border[rb1].yUpper; j++ ) {
+        xindex =  lut.border[rb1].xPixel[j];
+        PHMD[j * ( xSide + 1 ) + xindex] -= 1;
       }
     }
-    if(rb2){
-      for(j = lut.border[rb2].yLower;
-	  j <= lut.border[rb2].yUpper; j++ ){
-	xindex =  lut.border[rb2].xPixel[j];
-	PHMD[j*(xSide+1) + xindex] -= 1;
+    if ( rb2 ) {
+      for ( j = lut.border[rb2].yLower;
+            j <= lut.border[rb2].yUpper; j++ ) {
+        xindex =  lut.border[rb2].xPixel[j];
+        PHMD[j * ( xSide + 1 ) + xindex] -= 1;
       }
     }
 
     /* correcting border effects */
 
     /* note: if max1<min1, nothing should be done! */
-    for(j=min1; j<=max1; ++j){ PHMD[j*(xSide+1)] += 1; }
+    for ( j = min1; j <= max1; ++j ) {
+      PHMD[j * ( xSide + 1 )] += 1;
+    }
 
-    for(j=min2; j<=max2; ++j){ PHMD[j*(xSide+1)] += 1; }
+    for ( j = min2; j <= max2; ++j ) {
+      PHMD[j * ( xSide + 1 )] += 1;
+    }
 
   }
 
@@ -450,21 +457,21 @@ int main(int argc, char *argv[]){
   if ( fname ) {
     fp = fopen( fname, "w" );
   } else {
-    fp = fopen( FILEOUT , "w" );
+    fp = fopen( FILEOUT, "w" );
   }
 
-  if ( !fp ){
+  if ( !fp ) {
     ERROR( TESTCONSTRUCTPLUTC_EFILE, TESTCONSTRUCTPLUTC_MSGEFILE, 0 );
     return TESTCONSTRUCTPLUTC_EFILE;
   }
 
 
-  for(j=ySide-1; j>=0; --j){
-    for(i=0;i<xSide;++i){
-      fprintf( fp ," %d",  PHMD[j*(xSide+1) + i] );
+  for ( j = ySide - 1; j >= 0; --j ) {
+    for ( i = 0; i < xSide; ++i ) {
+      fprintf( fp, " %d",  PHMD[j * ( xSide + 1 ) + i] );
       fflush( fp );
     }
-    fprintf( fp ," \n");
+    fprintf( fp, " \n" );
     fflush( fp );
   }
 
@@ -474,17 +481,17 @@ int main(int argc, char *argv[]){
   /* Free memory and exit */
   /******************************************************************/
 
-  for (i=0; i<maxNBorders; ++i){
-    LALFree( lut.border[i].xPixel);
+  for ( i = 0; i < maxNBorders; ++i ) {
+    LALFree( lut.border[i].xPixel );
   }
 
-  LALFree( lut.border);
-  LALFree( lut.bin);
+  LALFree( lut.border );
+  LALFree( lut.bin );
 
-  LALFree( PHMD);
+  LALFree( PHMD );
 
-  LALFree( patch.xCoor);
-  LALFree( patch.yCoor);
+  LALFree( patch.xCoor );
+  LALFree( patch.yCoor );
 
   LALCheckMemoryLeaks();
 
