@@ -13,8 +13,8 @@
 *
 *  You should have received a copy of the GNU General Public License
 *  along with with program; see the file COPYING. If not, write to the
-*  Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-*  MA  02111-1307  USA
+*  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+*  MA  02110-1301  USA
 */
 
 /**
@@ -41,7 +41,7 @@
  * \c sourcefile, whose format is specified below.  If absent, it
  * injects a monochromatic wave with intrinsic frequency 100~Hz, strain
  * amplitude 1000, and zero phase at the GPS epoch, arriving from the
- * direction RA=00h00m, dec=\f$0^\circ\f$.</li>
+ * direction RA=00h00m, dec= \f$ 0^\circ \f$ .</li>
  * <li>[<tt>-r</tt>] Reads a detector response function from the file
  * \c respfile, whose format is specified below.  If absent, it
  * generates raw dimensionless strain.</li>
@@ -75,42 +75,42 @@
  * Each line consists of a GPS epoch where the frequency, phase, and
  * Taylor coefficients are defined (\c INT8 nanoseconds), followed by
  * 7 or more whitespace-delimited \c REAL8 numbers: the + and
- * \f$\times\f$ wave amplitudes (dimensionless strain) and polarization angle
- * \f$\psi\f$ (degrees), the right ascension and declination (degrees), the
+ * \f$ \times \f$ wave amplitudes (dimensionless strain) and polarization angle
+ * \f$ \psi \f$ (degrees), the right ascension and declination (degrees), the
  * initial phase (degrees) and frequency (Hz), followed by zero or more
- * Taylor coefficients \f$f_k\f$ (Hz\f${}^k\f$).  Note that the wave amplitudes
+ * Taylor coefficients \f$ f_k \f$ (Hz \f$ {}^k \f$ ).  Note that the wave amplitudes
  * and polarization angle are read as \c REAL8, but are later cast to
  * \c REAL4.
  *
  * \par Format for \c respfile:
- * The response function \f$R(f)\f$
+ * The response function \f$ R(f) \f$
  * gives the real and imaginary components of the transformation
- * \e from ADC output \f$o\f$ \e to tidal strain \f$h\f$ via
- * \f$\tilde{h}(f)=R(f)\tilde{o}(f)\f$.  It is inverted internally to give
- * the detector <em>transfer function</em> \f$T(f)=1/R(f)\f$.  The format
- * \c respfile is a header specifying the GPS epoch \f$t_0\f$ at which
+ * \e from ADC output \f$ o \f$ \e to tidal strain \f$ h \f$ via
+ * \f$ \tilde{h}(f)=R(f)\tilde{o}(f) \f$ .  It is inverted internally to give
+ * the detector <em>transfer function</em> \f$ T(f)=1/R(f) \f$ .  The format
+ * \c respfile is a header specifying the GPS epoch \f$ t_0 \f$ at which
  * the response was taken (\c INT8 nanoseconds), the lowest frequency
- * \f$f_0\f$ at which the response is given (\c REAL8 Hz), and the
- * frequency sampling interval \f$\Delta f\f$ (\c REAL8 Hz):
+ * \f$ f_0 \f$ at which the response is given (\c REAL8 Hz), and the
+ * frequency sampling interval \f$ \Delta f \f$ (\c REAL8 Hz):
  *
  * <table><tr><td>
- * <tt># epoch = </tt>\f$t_0\f$</td></tr>
- * <tr><td><tt># f0 = </tt>\f$f_0\f$</td></tr>
- * <tr><td><tt># deltaF = </tt>\f$\Delta f\f$
+ * <tt># epoch = </tt> \f$ t_0 \f$ </td></tr>
+ * <tr><td><tt># f0 = </tt> \f$ f_0 \f$ </td></tr>
+ * <tr><td><tt># deltaF = </tt> \f$ \Delta f \f$
  * </td></tr></table>
  *
  * followed by two columns of \c REAL4 data giving the real
- * and imaginary components of \f$R(f_0+k\Delta f)\f$.
+ * and imaginary components of \f$ R(f_0+k\Delta f) \f$ .
  *
  * \par Format for \c outfile:
  * The ouput files generated by
- * this program consist of a two-line header giving the GPS epoch \f$t_0\f$
+ * this program consist of a two-line header giving the GPS epoch \f$ t_0 \f$
  * of the first time sample (\c INT8 nanoseconds) and the sampling
- * interval \f$\Delta t\f$ (\c REAL8 seconds):
+ * interval \f$ \Delta t \f$ (\c REAL8 seconds):
  *
  * <table><tr><td>
- * <tt># epoch = </tt>\f$t_0\f$</td></tr>
- * <tr><td><tt># deltaT = </tt>\f$\Delta t\f$
+ * <tt># epoch = </tt> \f$ t_0 \f$ </td></tr>
+ * <tr><td><tt># deltaT = </tt> \f$ \Delta t \f$
  * </td></tr></table>
  *
  * followed by a single column of \c REAL4 data
@@ -125,8 +125,8 @@
  * parameters are taken from <tt>\#define</tt>d constants.) The arguments
  * are passed to <tt>LALGenerateTaylorCW()</tt> to generate frequency and
  * phase timeseries.  The required sampling resolution for these
- * timeseries is estimated at \f$0.1/\sum_k\sqrt{|kf_0f_kT^{k-1}|}\f$, where
- * \f$T\f$ is the duration of the waveform, to ensure that later
+ * timeseries is estimated at \f$ 0.1/\sum_k\sqrt{|kf_0f_kT^{k-1}|} \f$ , where
+ * \f$ T \f$ is the duration of the waveform, to ensure that later
  * interpolation of the waveforms will give phases accurate to well
  * within a radian.
  *
@@ -141,14 +141,14 @@
 
 /** \name Error Codes */
 /** @{ */
-#define SIMULATETAYLORCWTESTC_ENORM  0	/**< Normal exit */
-#define SIMULATETAYLORCWTESTC_ESUB   1	/**< Subroutine failed */
-#define SIMULATETAYLORCWTESTC_EARG   2	/**< Error parsing arguments */
-#define SIMULATETAYLORCWTESTC_EVAL   3	/**< Input argument out of valid range */
-#define SIMULATETAYLORCWTESTC_EFILE  4	/**< Could not open file */
-#define SIMULATETAYLORCWTESTC_EINPUT 5	/**< Error reading file */
-#define SIMULATETAYLORCWTESTC_EMEM   6	/**< Out of memory */
-#define SIMULATETAYLORCWTESTC_EPRINT 7	/**< Wrote past end of message string */
+#define SIMULATETAYLORCWTESTC_ENORM  0  /**< Normal exit */
+#define SIMULATETAYLORCWTESTC_ESUB   1  /**< Subroutine failed */
+#define SIMULATETAYLORCWTESTC_EARG   2  /**< Error parsing arguments */
+#define SIMULATETAYLORCWTESTC_EVAL   3  /**< Input argument out of valid range */
+#define SIMULATETAYLORCWTESTC_EFILE  4  /**< Could not open file */
+#define SIMULATETAYLORCWTESTC_EINPUT 5  /**< Error reading file */
+#define SIMULATETAYLORCWTESTC_EMEM   6  /**< Out of memory */
+#define SIMULATETAYLORCWTESTC_EPRINT 7  /**< Wrote past end of message string */
 /** @} */
 
 /** \cond DONT_DOXYGEN */
@@ -212,9 +212,9 @@ do                                                                   \
 if ( lalDebugLevel & LALERROR )                                      \
 {                                                                    \
   XLALPrintError( "Error[0] %d: program %s, file %s, line %d, %s\n"   \
-		 "        %s %s\n", (code), *argv, __FILE__,         \
-		 __LINE__, "$Id$",                    \
-		 statement ? statement : "", (msg) );                \
+     "        %s %s\n", (code), *argv, __FILE__,         \
+     __LINE__, "$Id$",                    \
+     statement ? statement : "", (msg) );                \
 }                                                                    \
 while (0)
 
@@ -223,8 +223,8 @@ do                                                                   \
 if ( lalDebugLevel & LALINFO )                                       \
 {                                                                    \
   XLALPrintError( "Info[0]: program %s, file %s, line %d, %s\n"       \
-		 "        %s\n", *argv, __FILE__, __LINE__,          \
-		 "$Id$", (statement) );               \
+     "        %s\n", *argv, __FILE__, __LINE__,          \
+     "$Id$", (statement) );               \
 }                                                                    \
 while (0)
 
@@ -233,8 +233,8 @@ do                                                                   \
 if ( lalDebugLevel & LALWARNING )                                    \
 {                                                                    \
   XLALPrintError( "Warning[0]: program %s, file %s, line %d, %s\n"    \
-		 "        %s\n", *argv, __FILE__, __LINE__,          \
-		 "$Id$", (statement) );               \
+     "        %s\n", *argv, __FILE__, __LINE__,          \
+     "$Id$", (statement) );               \
 }                                                                    \
 while (0)
 
@@ -243,7 +243,7 @@ do                                                                   \
 if ( (func), (statusptr)->statusCode )                               \
 {                                                                    \
   ERROR( SIMULATETAYLORCWTESTC_ESUB, SIMULATETAYLORCWTESTC_MSGESUB,  \
-	 "Function call \"" #func "\" failed:" );                    \
+   "Function call \"" #func "\" failed:" );                    \
   return SIMULATETAYLORCWTESTC_ESUB;                                 \
 }                                                                    \
 while (0)
@@ -271,7 +271,7 @@ choose( UINT4 a, UINT4 b );
 
 
 int
-main(int argc, char **argv)
+main( int argc, char **argv )
 {
   /* Command-line parsing variables. */
   int arg;                         /* command-line argument counter */
@@ -309,11 +309,11 @@ main(int argc, char **argv)
     /* Parse source file option. */
     if ( !strcmp( argv[arg], "-s" ) ) {
       if ( argc > arg + 1 ) {
-	arg++;
-	sourcefile = argv[arg++];
+        arg++;
+        sourcefile = argv[arg++];
       } else {
-	ERROR( SIMULATETAYLORCWTESTC_EARG,
-	       SIMULATETAYLORCWTESTC_MSGEARG, 0 );
+        ERROR( SIMULATETAYLORCWTESTC_EARG,
+               SIMULATETAYLORCWTESTC_MSGEARG, 0 );
         XLALPrintError( USAGE, *argv );
         return SIMULATETAYLORCWTESTC_EARG;
       }
@@ -321,11 +321,11 @@ main(int argc, char **argv)
     /* Parse response file option. */
     else if ( !strcmp( argv[arg], "-r" ) ) {
       if ( argc > arg + 1 ) {
-	arg++;
-	respfile = argv[arg++];
+        arg++;
+        respfile = argv[arg++];
       } else {
-	ERROR( SIMULATETAYLORCWTESTC_EARG,
-	       SIMULATETAYLORCWTESTC_MSGEARG, 0 );
+        ERROR( SIMULATETAYLORCWTESTC_EARG,
+               SIMULATETAYLORCWTESTC_MSGEARG, 0 );
         XLALPrintError( USAGE, *argv );
         return SIMULATETAYLORCWTESTC_EARG;
       }
@@ -333,11 +333,11 @@ main(int argc, char **argv)
     /* Parse output file option. */
     else if ( !strcmp( argv[arg], "-o" ) ) {
       if ( argc > arg + 1 ) {
-	arg++;
-	outfile = argv[arg++];
+        arg++;
+        outfile = argv[arg++];
       } else {
-	ERROR( SIMULATETAYLORCWTESTC_EARG,
-	       SIMULATETAYLORCWTESTC_MSGEARG, 0 );
+        ERROR( SIMULATETAYLORCWTESTC_EARG,
+               SIMULATETAYLORCWTESTC_MSGEARG, 0 );
         XLALPrintError( USAGE, *argv );
         return SIMULATETAYLORCWTESTC_EARG;
       }
@@ -345,13 +345,13 @@ main(int argc, char **argv)
     /* Parse detector location option. */
     else if ( !strcmp( argv[arg], "-l" ) ) {
       if ( argc > arg + 3 ) {
-	arg++;
-	site = argv[arg++];
-	earthfile = argv[arg++];
-	sunfile = argv[arg++];
+        arg++;
+        site = argv[arg++];
+        earthfile = argv[arg++];
+        sunfile = argv[arg++];
       } else {
-	ERROR( SIMULATETAYLORCWTESTC_EARG,
-	       SIMULATETAYLORCWTESTC_MSGEARG, 0 );
+        ERROR( SIMULATETAYLORCWTESTC_EARG,
+               SIMULATETAYLORCWTESTC_MSGEARG, 0 );
         XLALPrintError( USAGE, *argv );
         return SIMULATETAYLORCWTESTC_EARG;
       }
@@ -359,14 +359,14 @@ main(int argc, char **argv)
     /* Parse output timing option. */
     else if ( !strcmp( argv[arg], "-t" ) ) {
       if ( argc > arg + 4 ) {
-	arg++;
-	sec = atoi( argv[arg++] );
-	nsec = atoi( argv[arg++] );
-	npt = atoi( argv[arg++] );
-	dt = atof( argv[arg++] );
+        arg++;
+        sec = atoi( argv[arg++] );
+        nsec = atoi( argv[arg++] );
+        npt = atoi( argv[arg++] );
+        dt = atof( argv[arg++] );
       } else {
-	ERROR( SIMULATETAYLORCWTESTC_EARG,
-	       SIMULATETAYLORCWTESTC_MSGEARG, 0 );
+        ERROR( SIMULATETAYLORCWTESTC_EARG,
+               SIMULATETAYLORCWTESTC_MSGEARG, 0 );
         XLALPrintError( USAGE, *argv );
         return SIMULATETAYLORCWTESTC_EARG;
       }
@@ -374,13 +374,13 @@ main(int argc, char **argv)
     /* Parse heterodyning option. */
     else if ( !strcmp( argv[arg], "-h" ) ) {
       if ( argc > arg + 4 ) {
-	arg++;
-	hsec = atoi( argv[arg++] );
-	hnsec = atoi( argv[arg++] );
-	fh = atof( argv[arg++] );
+        arg++;
+        hsec = atoi( argv[arg++] );
+        hnsec = atoi( argv[arg++] );
+        fh = atof( argv[arg++] );
       } else {
-	ERROR( SIMULATETAYLORCWTESTC_EARG,
-	       SIMULATETAYLORCWTESTC_MSGEARG, 0 );
+        ERROR( SIMULATETAYLORCWTESTC_EARG,
+               SIMULATETAYLORCWTESTC_MSGEARG, 0 );
         XLALPrintError( USAGE, *argv );
         return SIMULATETAYLORCWTESTC_EARG;
       }
@@ -388,10 +388,10 @@ main(int argc, char **argv)
     /* Parse debug level option. */
     else if ( !strcmp( argv[arg], "-d" ) ) {
       if ( argc > arg + 1 ) {
-	arg++;
-      }else{
-	ERROR( SIMULATETAYLORCWTESTC_EARG,
-	       SIMULATETAYLORCWTESTC_MSGEARG, 0 );
+        arg++;
+      } else {
+        ERROR( SIMULATETAYLORCWTESTC_EARG,
+               SIMULATETAYLORCWTESTC_MSGEARG, 0 );
         XLALPrintError( USAGE, *argv );
         return SIMULATETAYLORCWTESTC_EARG;
       }
@@ -399,7 +399,7 @@ main(int argc, char **argv)
     /* Check for unrecognized options. */
     else if ( argv[arg][0] == '-' ) {
       ERROR( SIMULATETAYLORCWTESTC_EARG,
-	     SIMULATETAYLORCWTESTC_MSGEARG, 0 );
+             SIMULATETAYLORCWTESTC_MSGEARG, 0 );
       XLALPrintError( USAGE, *argv );
       return SIMULATETAYLORCWTESTC_EARG;
     }
@@ -417,37 +417,37 @@ main(int argc, char **argv)
   /* Set up output structure and wave start and stop times. */
   {
     INT8 epochOut = nsec;    /* output epoch */
-    epochOut += 1000000000LL*sec;
+    epochOut += 1000000000LL * sec;
     tStart = epochOut - 1000000000LL;
-    memset( &output, 0, sizeof(REAL4TimeSeries) );
-    I8ToLIGOTimeGPS( &(output.epoch), epochOut );
+    memset( &output, 0, sizeof( REAL4TimeSeries ) );
+    I8ToLIGOTimeGPS( &( output.epoch ), epochOut );
     output.deltaT = dt;
     snprintf( output.name, LALNameLength, "Taylor CW waveform" );
-    SUB( LALSCreateVector( &stat, &(output.data), npt ), &stat );
-    memset( output.data->data, 0, npt*sizeof(REAL4) );
-    tStop = epochOut + 1000000000LL*(INT8)( dt*npt + 1.0 );
+    SUB( LALSCreateVector( &stat, &( output.data ), npt ), &stat );
+    memset( output.data->data, 0, npt * sizeof( REAL4 ) );
+    tStop = epochOut + 1000000000LL * ( INT8 )( dt * npt + 1.0 );
     output.f0 = fh;
   }
   /* Adjust wave start and stop times so that they will almost
      certainly cover the output timespan even after barycentring. */
   if ( site ) {
-    tStart -= (INT8)( (1.1e9)*LAL_AU_SI/LAL_C_SI );
-    tStop += (INT8)( (1.1e9)*LAL_AU_SI/LAL_C_SI );
+    tStart -= ( INT8 )( ( 1.1e9 ) * LAL_AU_SI / LAL_C_SI );
+    tStop += ( INT8 )( ( 1.1e9 ) * LAL_AU_SI / LAL_C_SI );
   }
 
 
   /* Set up detector structure. */
-  memset( &detector, 0, sizeof(PulsarDetectorResponse) );
-  COMPLEX8FrequencySeries * transfer = (COMPLEX8FrequencySeries *)
-    LALMalloc( sizeof(COMPLEX8FrequencySeries) );
-  if ( !(transfer) ) {
+  memset( &detector, 0, sizeof( PulsarDetectorResponse ) );
+  COMPLEX8FrequencySeries *transfer = ( COMPLEX8FrequencySeries * )
+                                      LALMalloc( sizeof( COMPLEX8FrequencySeries ) );
+  if ( !( transfer ) ) {
     ERROR( SIMULATETAYLORCWTESTC_EMEM,
-	   SIMULATETAYLORCWTESTC_MSGEMEM, 0 );
+           SIMULATETAYLORCWTESTC_MSGEMEM, 0 );
     return SIMULATETAYLORCWTESTC_EMEM;
   }
   detector.heterodyneEpoch.gpsSeconds = hsec;
   detector.heterodyneEpoch.gpsNanoSeconds = hnsec;
-  memset( transfer, 0, sizeof(COMPLEX8FrequencySeries) );
+  memset( transfer, 0, sizeof( COMPLEX8FrequencySeries ) );
   if ( respfile ) {
     REAL4VectorSequence *resp = NULL; /* response as vector sequence */
     COMPLEX8Vector *response = NULL;  /* response as complex vector */
@@ -455,7 +455,7 @@ main(int argc, char **argv)
 
     if ( ( fp = fopen( respfile, "r" ) ) == NULL ) {
       ERROR( SIMULATETAYLORCWTESTC_EFILE,
-	     SIMULATETAYLORCWTESTC_MSGEFILE, respfile );
+             SIMULATETAYLORCWTESTC_MSGEFILE, respfile );
       return SIMULATETAYLORCWTESTC_EFILE;
     }
 
@@ -468,7 +468,7 @@ main(int argc, char **argv)
                     &( transfer->deltaF ) ) == 1 );
     if ( !ok ) {
       ERROR( SIMULATETAYLORCWTESTC_EINPUT,
-	     SIMULATETAYLORCWTESTC_MSGEINPUT, respfile );
+             SIMULATETAYLORCWTESTC_MSGEINPUT, respfile );
       return SIMULATETAYLORCWTESTC_EINPUT;
     }
 
@@ -477,11 +477,11 @@ main(int argc, char **argv)
     fclose( fp );
     if ( resp->vectorLength != 2 ) {
       ERROR( SIMULATETAYLORCWTESTC_EINPUT,
-	     SIMULATETAYLORCWTESTC_MSGEINPUT, respfile );
+             SIMULATETAYLORCWTESTC_MSGEINPUT, respfile );
       return SIMULATETAYLORCWTESTC_EINPUT;
     }
     SUB( LALCCreateVector( &stat, &response, resp->length ), &stat );
-    memcpy( response->data, resp->data, 2*resp->length*sizeof(REAL4) );
+    memcpy( response->data, resp->data, 2 * resp->length * sizeof( REAL4 ) );
     SUB( LALSDestroyVectorSequence( &stat, &resp ), &stat );
 
     /* Convert response function to a transfer function. */
@@ -510,32 +510,33 @@ main(int argc, char **argv)
   EphemerisData *lephem = NULL;
   if ( site ) {
     /* Set detector location. */
-    if ( !strcmp( site, "LHO" ) )
+    if ( !strcmp( site, "LHO" ) ) {
       i = LALDetectorIndexLHODIFF;
-    else if ( !strcmp( site, "LLO" ) )
+    } else if ( !strcmp( site, "LLO" ) ) {
       i = LALDetectorIndexLLODIFF;
-    else if ( !strcmp( site, "VIRGO" ) )
+    } else if ( !strcmp( site, "VIRGO" ) ) {
       i = LALDetectorIndexVIRGODIFF;
-    else if ( !strcmp( site, "GEO600" ) )
+    } else if ( !strcmp( site, "GEO600" ) ) {
       i = LALDetectorIndexGEO600DIFF;
-    else if ( !strcmp( site, "TAMA300" ) )
+    } else if ( !strcmp( site, "TAMA300" ) ) {
       i = LALDetectorIndexTAMA300DIFF;
-    else if ( !strcmp( site, "CIT40" ) )
+    } else if ( !strcmp( site, "CIT40" ) ) {
       i = LALDetectorIndexCIT40DIFF;
-    else {
+    } else {
       ERROR( SIMULATETAYLORCWTESTC_EVAL,
-	     SIMULATETAYLORCWTESTC_MSGEVAL, "Unrecognized site:" );
-      if ( lalDebugLevel & LALERROR )
-	XLALPrintError( "%s", site );
+             SIMULATETAYLORCWTESTC_MSGEVAL, "Unrecognized site:" );
+      if ( lalDebugLevel & LALERROR ) {
+        XLALPrintError( "%s", site );
+      }
       return SIMULATETAYLORCWTESTC_EVAL;
     }
-    lsite = (LALDetector *)LALMalloc( sizeof(LALDetector) );
-    if ( !(lsite) ) {
+    lsite = ( LALDetector * )LALMalloc( sizeof( LALDetector ) );
+    if ( !( lsite ) ) {
       ERROR( SIMULATETAYLORCWTESTC_EMEM,
-	     SIMULATETAYLORCWTESTC_MSGEMEM, 0 );
+             SIMULATETAYLORCWTESTC_MSGEMEM, 0 );
       return SIMULATETAYLORCWTESTC_EMEM;
     }
-    *(lsite) = lalCachedDetectors[i];
+    *( lsite ) = lalCachedDetectors[i];
 
     /* Read ephemerides. */
     XLAL_CHECK_MAIN( ( lephem = XLALInitBarycenter( earthfile, sunfile ) ) != NULL, XLAL_EFUNC );
@@ -544,8 +545,8 @@ main(int argc, char **argv)
 
   /* Set up units for the above structures. */
   output.sampleUnits = lalADCCountUnit;
-  if (XLALUnitDivide( &(transfer->sampleUnits),
-                      &lalADCCountUnit, &lalStrainUnit ) == NULL) {
+  if ( XLALUnitDivide( &( transfer->sampleUnits ),
+                       &lalADCCountUnit, &lalStrainUnit ) == NULL ) {
     return LAL_EXLAL;
   }
 
@@ -561,7 +562,7 @@ main(int argc, char **argv)
   if ( sourcefile ) {
     if ( ( fp = fopen( sourcefile, "r" ) ) == NULL ) {
       ERROR( SIMULATETAYLORCWTESTC_EFILE,
-	     SIMULATETAYLORCWTESTC_MSGEFILE, sourcefile );
+             SIMULATETAYLORCWTESTC_MSGEFILE, sourcefile );
       return SIMULATETAYLORCWTESTC_EFILE;
     }
   }
@@ -574,38 +575,40 @@ main(int argc, char **argv)
     CHAR message[MSGLEN];      /* warning/info messages */
 
     /* Initialize output structures. */
-    memset( &waveform, 0, sizeof(PulsarCoherentGW) );
+    memset( &waveform, 0, sizeof( PulsarCoherentGW ) );
     signalvec = output;
     signalvec.data = NULL;
 
     /* Read and convert input line. */
-    memset( &params, 0, sizeof(TaylorCWParamStruc) );
-    I8ToLIGOTimeGPS( &(params.epoch), tStart );
+    memset( &params, 0, sizeof( TaylorCWParamStruc ) );
+    I8ToLIGOTimeGPS( &( params.epoch ), tStart );
     params.position.system = COORDINATESYSTEM_EQUATORIAL;
     if ( sourcefile ) {
       REAL8Vector *input = NULL; /* input parameters */
       ok &= ( fscanf( fp, "%" LAL_INT8_FORMAT, &epoch ) == 1 );
       if ( ok ) {
-	SUB( LALDReadVector( &stat, &input, fp, 1 ), &stat );
-	ok &= ( input->length > 6 );
+        SUB( LALDReadVector( &stat, &input, fp, 1 ), &stat );
+        ok &= ( input->length > 6 );
       }
       if ( ok ) {
-	params.aPlus = input->data[0];
-	params.aCross = input->data[1];
-	params.psi = LAL_PI*input->data[2]/180.0;
-	params.position.longitude = LAL_PI*input->data[3]/180.0;
-	params.position.latitude = LAL_PI*input->data[4]/180.0;
-	params.phi0 = LAL_PI*input->data[5]/180.0;
-	params.f0 = input->data[6];
-	if ( input->length > 7 ) {
-	  SUB( LALDCreateVector( &stat, &(params.f),
-				 input->length - 7 ), &stat );
-	  for ( i = 0; i < input->length - 7; i++ )
-	    params.f->data[i] = input->data[i+7];
-	}
+        params.aPlus = input->data[0];
+        params.aCross = input->data[1];
+        params.psi = LAL_PI * input->data[2] / 180.0;
+        params.position.longitude = LAL_PI * input->data[3] / 180.0;
+        params.position.latitude = LAL_PI * input->data[4] / 180.0;
+        params.phi0 = LAL_PI * input->data[5] / 180.0;
+        params.f0 = input->data[6];
+        if ( input->length > 7 ) {
+          SUB( LALDCreateVector( &stat, &( params.f ),
+                                 input->length - 7 ), &stat );
+          for ( i = 0; i < input->length - 7; i++ ) {
+            params.f->data[i] = input->data[i + 7];
+          }
+        }
+      }
+      if ( input ) {
+        SUB( LALDDestroyVector( &stat, &input ), &stat );
       }
-      if ( input )
-	SUB( LALDDestroyVector( &stat, &input ), &stat );
     } else {
       params.aPlus = APLUS;
       params.aCross = ACROSS;
@@ -620,95 +623,101 @@ main(int argc, char **argv)
        time. */
     if ( params.f ) {
       UINT4 length = params.f->length; /* number of coefficients */
-      REAL8 t = (1.0e-9)*(REAL4)( tStart - epoch ); /* time shift */
+      REAL8 t = ( 1.0e-9 ) * ( REAL4 )( tStart - epoch ); /* time shift */
       REAL8 tN = 1.0;   /* t raised to various powers */
       REAL8 fFac = 1.0; /* fractional change in frequency */
       REAL8 tFac = 1.0; /* time integral of fFac */
       REAL8 *fData = params.f->data; /* pointer to coeficients */
       for ( i = 0; i < length; i++ ) {
-	REAL8 tM = 1.0; /* t raised to various powers */
-	fFac += fData[i]*( tN *= t );
-	tFac += fData[i]*tN/( i + 2.0 );
-	for ( j = i + 1; j < length; j++ )
-	  fData[i] += choose( j + 1, i + 1 )*fData[j]*( tM *= t );
+        REAL8 tM = 1.0; /* t raised to various powers */
+        fFac += fData[i] * ( tN *= t );
+        tFac += fData[i] * tN / ( i + 2.0 );
+        for ( j = i + 1; j < length; j++ ) {
+          fData[i] += choose( j + 1, i + 1 ) * fData[j] * ( tM *= t );
+        }
       }
-      params.phi0 += LAL_TWOPI*params.f0*t*tFac;
+      params.phi0 += LAL_TWOPI * params.f0 * t * tFac;
       params.f0 *= fFac;
-      for ( i = 0; i < length; i++ )
-	fData[i] /= fFac;
+      for ( i = 0; i < length; i++ ) {
+        fData[i] /= fFac;
+      }
     }
 
     if ( ok ) {
       REAL4 *sigData, *outData; /* pointers to time series data */
-      REAL4 t = (1.0e-9)*(REAL4)( tStop - tStart ); /* duration */
+      REAL4 t = ( 1.0e-9 ) * ( REAL4 )( tStop - tStart ); /* duration */
       REAL4 dtInv = 0.0; /* sampling rate for waveform */
 
       /* Set remaining parameters, and generate waveform. */
       if ( params.f ) {
-	REAL4 tN = 1.0; /* t raised to various powers */
-	for ( i = 0; i < params.f->length; i++ ) {
-	  dtInv += sqrt( (i+1)*fabs( params.f->data[i] )*tN );
-	  tN *= t;
-	}
-	dtInv *= 10.0*sqrt( fabs( params.f0 ) );
+        REAL4 tN = 1.0; /* t raised to various powers */
+        for ( i = 0; i < params.f->length; i++ ) {
+          dtInv += sqrt( ( i + 1 ) * fabs( params.f->data[i] ) * tN );
+          tN *= t;
+        }
+        dtInv *= 10.0 * sqrt( fabs( params.f0 ) );
       }
-      if ( dtInv < 1.0/t ) {
-	params.deltaT = t;
-	params.length = 2;
+      if ( dtInv < 1.0 / t ) {
+        params.deltaT = t;
+        params.length = 2;
       } else {
-	params.deltaT = 1.0/dtInv;
-	params.length = (UINT4)( t*dtInv ) + 2;
+        params.deltaT = 1.0 / dtInv;
+        params.length = ( UINT4 )( t * dtInv ) + 2;
       }
       SUB( LALGenerateTaylorCW( &stat, &waveform, &params ), &stat );
       if ( params.dfdt > 2.0 ) {
-	/* snprintf() can't seem to print floating-point formats.
-        snprintf( message, MSGLEN,
-                     "Waveform sampling interval is too large:\n"
-                     "\tmaximum df*dt = %f", params.dfdt );
-	*/
-	INT4 code = sprintf( message,
-			     "Waveform sampling interval is too large:\n"
-			     "\tmaximum df*dt = %f", params.dfdt );
-	if ( code >= MSGLEN || code < 0 ) {
-	  ERROR( SIMULATETAYLORCWTESTC_EPRINT,
-		 SIMULATETAYLORCWTESTC_MSGEPRINT, 0 );
-	  return SIMULATETAYLORCWTESTC_EPRINT;
-	}
+        /* snprintf() can't seem to print floating-point formats.
+              snprintf( message, MSGLEN,
+                           "Waveform sampling interval is too large:\n"
+                           "\tmaximum df*dt = %f", params.dfdt );
+        */
+        INT4 code = sprintf( message,
+                             "Waveform sampling interval is too large:\n"
+                             "\tmaximum df*dt = %f", params.dfdt );
+        if ( code >= MSGLEN || code < 0 ) {
+          ERROR( SIMULATETAYLORCWTESTC_EPRINT,
+                 SIMULATETAYLORCWTESTC_MSGEPRINT, 0 );
+          return SIMULATETAYLORCWTESTC_EPRINT;
+        }
         WARNING( message );
       }
-      SUB( LALSCreateVector( &stat, &(signalvec.data), npt ), &stat );
+      SUB( LALSCreateVector( &stat, &( signalvec.data ), npt ), &stat );
       SUB( LALPulsarSimulateCoherentGW( &stat, &signalvec, &waveform,
-				  &detector ), &stat );
-      if ( params.f )
-	SUB( LALDDestroyVector( &stat, &(params.f) ), &stat );
+                                        &detector ), &stat );
+      if ( params.f ) {
+        SUB( LALDDestroyVector( &stat, &( params.f ) ), &stat );
+      }
 
       /* Inject waveform into output. */
       sigData = signalvec.data->data;
       outData = output.data->data;
-      for ( i = 0; i < (UINT4)( npt ); i++ )
-	outData[i] += sigData[i];
+      for ( i = 0; i < ( UINT4 )( npt ); i++ ) {
+        outData[i] += sigData[i];
+      }
 
       /* Clean up memory. */
       SUB( LALSDestroyVectorSequence( &stat, &( waveform.a->data ) ),
            &stat );
       SUB( LALSDestroyVector( &stat, &( waveform.f->data ) ),
-	   &stat );
+           &stat );
       SUB( LALDDestroyVector( &stat, &( waveform.phi->data ) ),
-	   &stat );
+           &stat );
       LALFree( waveform.a );
       LALFree( waveform.f );
       LALFree( waveform.phi );
-      SUB( LALSDestroyVector( &stat, &(signalvec.data) ), &stat );
+      SUB( LALSDestroyVector( &stat, &( signalvec.data ) ), &stat );
     }
 
     /* Inject only one signal if there is no sourcefile. */
-    if ( !sourcefile )
+    if ( !sourcefile ) {
       ok = 0;
+    }
   }
 
   /* Input file is exhausted (or has a badly-formatted line ). */
-  if ( sourcefile )
+  if ( sourcefile ) {
     fclose( fp );
+  }
 
 
   /*******************************************************************
@@ -719,15 +728,16 @@ main(int argc, char **argv)
   if ( outfile ) {
     if ( ( fp = fopen( outfile, "w" ) ) == NULL ) {
       ERROR( SIMULATETAYLORCWTESTC_EFILE,
-	     SIMULATETAYLORCWTESTC_MSGEFILE, outfile );
+             SIMULATETAYLORCWTESTC_MSGEFILE, outfile );
       return SIMULATETAYLORCWTESTC_EFILE;
     }
-    epoch = 1000000000LL*(INT8)( output.epoch.gpsSeconds );
-    epoch += (INT8)( output.epoch.gpsNanoSeconds );
+    epoch = 1000000000LL * ( INT8 )( output.epoch.gpsSeconds );
+    epoch += ( INT8 )( output.epoch.gpsNanoSeconds );
     fprintf( fp, "# epoch = %" LAL_INT8_FORMAT "\n", epoch );
     fprintf( fp, "# deltaT = %23.16e\n", output.deltaT );
-    for ( i = 0; i < output.data->length; i++ )
-      fprintf( fp, "%16.9e\n", (REAL4)( output.data->data[i] ) );
+    for ( i = 0; i < output.data->length; i++ ) {
+      fprintf( fp, "%16.9e\n", ( REAL4 )( output.data->data[i] ) );
+    }
     fclose( fp );
   }
 
@@ -753,8 +763,8 @@ void
 I8ToLIGOTimeGPS( LIGOTimeGPS *output, INT8 input )
 {
   INT8 s = input / 1000000000LL;
-  output->gpsSeconds = (INT4)( s );
-  output->gpsNanoSeconds = (INT4)( input - 1000000000LL*s );
+  output->gpsSeconds = ( INT4 )( s );
+  output->gpsNanoSeconds = ( INT4 )( input - 1000000000LL * s );
   return;
 }
 
@@ -770,6 +780,6 @@ choose( UINT4 a, UINT4 b )
     numer *= a - b + lal_index;
     denom *= lal_index;
   }
-  return numer/denom;
+  return numer / denom;
 }
 /** \endcond */
